"""
Module containing a simple logger.


$VHIST distribution: v 0.50.3 2007-02-10 12:10:20 $


This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

$Id: logger.py 1967 2010-04-29 21:48:23Z ahuesgen $
"""

import sys

__logFormats = {
    1 : "%s",
    2 : "* %s",
    3 : "%s", # !sv
    4 : "  %s",
    5 : "    %s"}

__errorFormat = "*** ERROR: %s"
__warnFormat  = "*** WARNING: %s"

LOG_LEVEL_OFF = 0
LOG_LEVEL_MAX = 5

__logLevel = 2


def setLogLevel(level):
    global __logLevel
    __logLevel = level

def log(level, message, *args):
    if level <=  __logLevel:
        if message != "":
            if len(args) > 0:
                msg = __logFormats[level] % (message % args)
            else:
                msg = __logFormats[level] % message
        else:
            msg = ""
        print msg
        sys.stdout.flush()


def error(message, *args):
    if len(args) > 0:
        msg = __errorFormat % (message % args)
    else:
        msg = __errorFormat % message
    print msg
    sys.stdout.flush()


def warning(message, *args):
    if __logLevel > 0:
        if len(args) > 0:
            msg = __warnFormat % (message % args)
        else:
            msg = __warnFormat % message
        print msg
        sys.stdout.flush()

def abort(errcode, message, *args):
    error(message, *args)
    sys.exit(errcode)
