"""

This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

$Id: previewpage.py 2684 2013-04-16 14:24:21Z ahuesgen $
"""

import copy

import imagehandler
import resources
import pdflayouter
import pdfadvobjs
import pdflayouter
import layoutitem

def createImageObjects(vfile, imageFilenames):
    imageObjs = [imagehandler.Image(filename) for filename in imageFilenames]
    metaDatas = [i.meta for i in imageObjs]

    imagePdfObjs = []
    for image in imageObjs:
        id = vfile.getFirstFreeID()
        obj = image.genPdfObject(id, 0)
        imagePdfObjs.append(obj)
        vfile.addObject(obj)
    return metaDatas, imagePdfObjs


def layoutPreview(image):
    w = image["meta"].width
    h = image["meta"].height
    pdfname = image["pdfname"]
    basename = image["basename"]
    subtitle = image["subtitle"]
    
    caption = "*%s:* %s" % (basename, subtitle)
    
    layouter = pdflayouter.PDFLayouter(79, 10, False)
    pages = layouter.layoutText(image, caption)
    
    captionText = pages[0]
    layoutParams = dict(pdfname=pdfname, x=0, y=0, width=w, height=h,
            caption=captionText)
    
    return layoutParams


def layoutPreviews(images):
    litems = []
    
    y = 760
    x = 60
    for image in images:
            layoutParams = layoutPreview(image)
            gx = x + layoutParams["x"]
            gy = y + layoutParams["y"]
            width = layoutParams["width"]
            height = layoutParams["height"]
            pdfname = layoutParams["pdfname"]
            
            graphic = layoutitem.Graphic(width, height, pdfname)
            litem = layoutitem.LayoutItem(gx, gy, graphic)
            litems.append(litem)
            
            cx = x
            cy = gy - height - 20
            caption = layoutParams["caption"]
            litem = layoutitem.LayoutItem(cx, cy, caption)
            litems.append(litem)
            y = cy - getNumLayoutLines(caption) * 8
    
    return litems


def createPages(vfile, pagesObj, resourcesObj, images):
    szFooter = u"File created: FIXME!!!, title page"
    szTitle = u"PREVIEWS"
    
    #layouter = pdflayouter.PDFLayouter(CHARS_PER_COL, LINES_PER_PAGE, False)
    #pages = layouter.layoutText(title)
    #footer = layouter.genSimpleStream(szFooter)
    #title = layouter.genSimpleStream(szTitle)
    
    # prepare loop
    nextPageNum = pagesObj.get("/Count")
    
    for image in [images]:
        nextID = vfile.getFirstFreeID()
        contentObj = pdfadvobjs.PDFContentObject(nextID, 0)
        contentObj.addImage(10, 500, 100, 100, '/Im1')
        vfile.addObject(contentObj)
        #addStandardLayout(contentObj, title, page, footer)
        
        nextID = vfile.getFirstFreeID()
        pageObj = pdfadvobjs.PDFPageObject(nextID, 0, pagesObj, resourcesObj,
                contentObj)
        vfile.addObject(pageObj)
        pagesObj.addPage(pageObj)


def PreviewPages(vfile, pagesObj, images):
    images = copy.deepcopy(images)
    imageFilenames = [i['filename'] for i in images]
    
    metaDatas, imageObjs = createImageObjects(vfile, imageFilenames)
    for image, metadata in zip(images, metaDatas):
        image["metadata"] = metaData
    
    id = vfile.getFirstFreeID()
    resourcesObj, imageNames = resources.genImageResources(imageObjs, id, 0)
    vfile.addObject(resourcesObj)
    
    for image, name in zip(images, imageNames):
        image["pdfname"] = name
    
    createPage(vfile, pagesObj, resourcesObj, imageObjs)
    
    # DONE create Image objects
    # DONE create Resources object
    # TODO create Page objects PARTLY DONE
    # TODO create Contents objects PARTLY DONE
    # TODOlayout images + subtitles
    
    
    
