"""
Module containing unittests for pdflexer.py.



This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

$Id: test_userinterface.py 1071 2008-05-25 18:58:08Z ahuesgen $
"""

import userinterface as ui
import unittest, verbosetestcase
import sys

class StdOutMock(object):
    def write(self, data):
        pass

class TestUserinterface(verbosetestcase.VerboseTestCase):
    def setUp(self):
        self.oldStdOut = sys.stdout
        self.oldStdErr = sys.stderr
        sys.stdout = StdOutMock()
        sys.stderr = StdOutMock()
    
    def tearDown(self):
        sys.stdout = self.oldStdOut
        sys.stderr = self.oldStdErr
    
    def testHelp(self):
        self.assertRaises(SystemExit, ui.parseCommandline, ["myapp", "--help"])
        self.assertRaises(SystemExit, ui.parseCommandline, ["myapp", "-h"])
    
    def testVersion(self):
        self.assertRaises(SystemExit, ui.parseCommandline,
                ["myapp", "--version"])
    
    #def testNoVHistFile(self):
    #    self.assertRaises(SystemExit, ui.parseCommandline, ["myapp"])
    
    #def testInvalidStepAttr(self):
    #    self.assertRaises(ui.CommandlineError, ui)

if __name__ == "__main__":
    unittest.main()
