"""
Module containing unittests for utilities.py.


This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

$Id: test_utilities.py 1071 2008-05-25 18:58:08Z ahuesgen $
"""

import utilities
import unittest, verbosetestcase


class TestUtilitites(verbosetestcase.VerboseTestCase):
    
    def setUp(self):
        pass
    
    def tearDown(self):
        pass
    
    def testCheckType(self):
        testStr = "string"
        
        # test with wrong type
        self.assertRaises(TypeError, utilities.checkType, testStr, int)
        
        # test with correct type (if an exception is thrown, the function malfunctions)
        utilities.checkType(testStr, str)
    
    
    def testValidateTypeMultiple(self):
        testStr = "string"
        
        # test with several wrong types
        self.assertRaises(TypeError, utilities.checkType, testStr, (bool, int))
        
        # test with several types, first is right (if an exception is thrown,
        # the function malfunctions)
        utilities.checkType(testStr, (str, int, bool))
        # test with several types, second is right (if an exception is thrown,
        # the function malfunctions)
        utilities.checkType(testStr, (int, str, bool))
        # test with several types, last is right (if an exception is thrown,
        # the function malfunctions)
        utilities.checkType(testStr, (int, bool, str))
    
    
    def testValidateTypeHierarchy(self):
        testException = ArithmeticError("foo")
        
        
        # test for baseclass
        utilities.checkType(testException, Exception)
        
        # test for exact class
        utilities.checkType(testException, ArithmeticError)
        
        # test for derived class (should throw an exception)
        self.assertRaises(TypeError, utilities.checkType,
                testException, FloatingPointError)
        
        # test for several types in the hierarchy
        utilities.checkType(testException, (Exception, FloatingPointError))

if __name__ == "__main__":
    unittest.main()

