"""
Module containing unittests for vhisttags.py.



This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

$Id: test_vhisttags.py 1071 2008-05-25 18:58:08Z ahuesgen $
"""

import vhisttags
import unittest, verbosetestcase
import vhistconsts

class TestSectionTag(verbosetestcase.VerboseTestCase):
    def setUp(self):
        pass
    
    def tearDown(self):
        pass
    
    def testTag1(self):
        pass
        """
        version = vhistconsts.VHIST_VERSION
        toolversion = vhistconsts.VHISTADD_VERSION_STRING
        title = "title"
        sectionPrefix = "this is a prefix"
        sectionPostfix = "this is a postfix"
        index = 1
        prevMD5 = "1234567890ABCDEF" * 2
        prevMarker = 12345
        expTag = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:title][left:16][size:000000000000]"
                "[index:1][md5section:00000000000000000000000000000000]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion)
        print "len", len(sectionPrefix) + len(sectionPostfix) + len(expTag)
        tag = vhisttags.SectionTag(title, sectionPrefix, index, prevMD5,
                prevMarker)
        self.assertEquals(tag.getTag(), expTag)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))
        
        tag.setSectionPostfix(sectionPostfix)
        expTag2 = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:title][left:16][size:000000000279][index:1]"
                "[md5section:35d5f3bea7716cc2c42ea98558923751]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion)
        
        self.assertEquals(tag.getTag(), expTag2)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))"""
    
    def testTag2(self):
        pass
        """
        version = vhistconsts.VHIST_VERSION
        toolversion = vhistconsts.VHISTADD_VERSION_STRING
        title = u"\xfc" # u umlaut
        utf8title = title.encode("utf-8")
        sectionPrefix = "this is a prefix"
        sectionPostfix = "this is a postfix"
        index = 1
        prevMD5 = "1234567890ABCDEF" * 2
        prevMarker = 12345
        expTag = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:%s][left:16][size:000000000000]"
                "[index:1][md5section:00000000000000000000000000000000]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion, utf8title)
        tag = vhisttags.SectionTag(title, sectionPrefix, index, prevMD5,
                prevMarker)
        self.assertEquals(tag.getTag(), expTag)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))
        
        tag.setSectionPostfix(sectionPostfix)
        expTag2 = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:%s][left:16][size:000000000276][index:1]"
                "[md5section:f237367f288d217417932354c5920ea0]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion, utf8title)
        
        self.assertEquals(tag.getTag(), expTag2)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))"""

    def testTagEscaping(self):
        pass
        """
        version = vhistconsts.VHIST_VERSION
        toolversion = vhistconsts.VHISTADD_VERSION_STRING
        title = "[][]\\"
        esctitle = "[\\][\\]\\\\"
        sectionPrefix = "this is a prefix"
        sectionPostfix = "this is a postfix"
        index = 1
        prevMD5 = "1234567890abcdef" * 2
        prevMarker = 12345
        expTag = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:%s][left:16][size:000000000000]"
                "[index:1][md5section:00000000000000000000000000000000]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion, esctitle)
        tag = vhisttags.SectionTag(title, sectionPrefix, index, prevMD5,
                prevMarker)
        self.assertEquals(tag.getTag(), expTag)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))
        
        tag.setSectionPostfix(sectionPostfix)
        expTag2 = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:%s][left:16][size:000000000282][index:1]"
                "[md5section:59c5ac49db3736c26f94a5e0f4a37f26]"
                "[previousmd5:1234567890abcdef1234567890abcdef]"
                "[previousmarker:12345]-->") % (version, toolversion, esctitle)
        
        self.assertEquals(tag.getTag(), expTag2)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))"""
    
    def testTagNoPrevTag(self):
        pass
        """
        version = vhistconsts.VHIST_VERSION
        toolversion = vhistconsts.VHISTADD_VERSION_STRING
        title = "noprevtag"
        sectionPrefix = "this is a prefix"
        sectionPostfix = "this is a postfix"
        index = 1
        prevMD5 = None
        prevMarker = None
        expTag = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:noprevtag][left:16][size:000000000000]"
                "[index:1][md5section:00000000000000000000000000000000]"
                "[previousmd5:][previousmarker:]-->") % (version, toolversion)
        tag = vhisttags.SectionTag(title, sectionPrefix, index, prevMD5,
                prevMarker)
        self.assertEquals(tag.getTag(), expTag)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))
        
        tag.setSectionPostfix(sectionPostfix)
        expTag2 = ("<--! $VHIST_SECTION [version:%s][creator:%s]"
                "[title:noprevtag][left:16][size:000000000246][index:1]"
                "[md5section:9f4b8e18e1d032e5f69f7abb45498a3a]"
                "[previousmd5:][previousmarker:]-->") % (version, toolversion)
        
        self.assertEquals(tag.getTag(), expTag2)
        self.assertEquals(tag.getTagSize(), len(tag.getTag()))"""

class TestEmbeddedFileTag(verbosetestcase.VerboseTestCase):
    def setUp(self):
        pass
    
    def tearDown(self):
        pass
    
    def testTag1(self):
        pass



if __name__ == "__main__":
    unittest.main()
