#!/usr/bin/env python
"""A small tool for extracting embedded data from a VHIST file,
see www.nf.mpg.de/vhist for more information.

This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

Author: Andreas Huesgen
$Id: vhistxl.py 908 2008-02-13 12:34:32Z ahuesgen $
"""
import os, re, zlib
vhistfilename = os.sys.argv[1]
vhistfile = open(vhistfilename, "rb")
data = vhistfile.read(); vhistfile.close()
curpos, nextfile = 0L, 1
regex = re.compile(r"<--! \$VHIST_EMBEDDEDFILE_BEGIN(.*?)"
                   r"\[filename:(?P<fn>([^\\\]]|(\\\\)|(\\\])|(\\n))+?)\](.*?)"
                   r"\[compression:(?P<cp>.*?)\](.*?)"
                   r"\[filesize:(?P<fs>[0-9]+?)\](.*?)"
                   r"\[cfilesize:(?P<cfs>[0-9]*?)\](.*?)"
                   r"\[offset:(?P<os>[0-9]*?)\](.*?)"
                   r"(.*?)-->", re.DOTALL)
found = regex.search(data, curpos)
while found is not None:
    g = found.group
    filename, compression, bytesize, cbytesize, filepos = (g("fn"), g("cp"),
            int(g("fs")), g("cfs") == "" or int(g("cfs")), found.end() + int(g("os")))
    filename = filename.replace("\\n", "\n").replace("\\]", "]").replace("\\\\", "\\")
    outfile = open("[%d]_%s" % (nextfile, filename), "wb")
    if compression == "none": outfile.write(data[filepos:filepos + bytesize])
    elif compression == "flate":
        outfile.write(zlib.decompress(data[filepos:filepos + cbytesize]))
        bytesize = cbytesize
    else: print "unknown compression method!"
    outfile.close()
    nextfile, curpos = nextfile + 1, filepos + bytesize
    found = regex.search(data, curpos)
