/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: stopwatch.h 2791 2013-05-06 11:24:28Z michael $
 */

#ifndef STOPWATCH_INCLUDED
#define STOPWATCH_INCLUDED

#include "misc_defines.h"
#include "logsource.h"

#include <QString>

namespace vhist
{

/**
 * @example stopwatch_example.cpp
 *
 * This example shows how to measure time intervals using the StopWatch
 * class.
 */

/**
 * A class to measure time intervals. This class measures the time
 * between two consecutive calls to the StopWatch::start and
 * StopWatch::stop methods. The results will be published using
 * the interface provided by the vhist::LogSource class.
 */
class VHIST_EXTERN StopWatch : public vhist::LogSource
{
    Q_OBJECT
    
    public:
	StopWatch(QObject *pLogTarget = NULL);
	virtual ~StopWatch();
    
    public:
        void start(const QString& title, bool abortPrevious = false);
        void stop(bool generateMessage = true);
    
    private:
        QString m_title;
        bool m_running;
        unsigned long m_startTime;
};

} // namespace

#endif // STOPWATCH_INCLUDED

