/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: inflater.h 2792 2013-05-06 11:25:27Z michael $
 */

#ifndef INFLATER_INCLUDED
#define INFLATER_INCLUDED

#include "../shared/misc_defines.h"

#include <zlib.h>

#include <QByteArray>

namespace vhist
{

/** @example inflate_example.cpp
 * 
 * An example which shows how to use the Inflater class.
 */

/**
 * A class designed for inflating (decompressing using the flate method)
 * streams of data. The Inflater reads chunks of data, inflates them and
 * returns the decompressed counterpart. The data must not be passed in
 * as one single QByteArray but can inflate the data incrementally by
 * calling inflateData several times with consecutive parts of the
 * data. This way, the amount of information in memory can be reduced to
 * a limited fixed size of the user's choice.
 */
class VHIST_EXTERN Inflater 
{
    public:
        Inflater();
        ~Inflater();
    
    public:
        QByteArray inflateData(QByteArray data);
        bool hasFinished();
        bool isValid();
        void reset();
    
    private:
        void init();
    
    private:
        z_stream m_stream;
        bool m_valid;
        bool m_finished;
        unsigned char *m_out;
        unsigned int m_iChunk;
};

} // namespace

#endif // INFLATER_INCLUDED

