/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: md5generator.h 2792 2013-05-06 11:25:27Z michael $
 */

#ifndef MD5GENERATOR_INCLUDED
#define MD5GENERATOR_INCLUDED

#include "../shared/misc_defines.h"

#include <QObject>

#include "md5.h"

class QByteArray;

namespace vhist
{


/**
 * @example md5generator_example.cpp
 *
 * This example shows how to generate a MD5 sum for a given chunk of
 * data.
 */

/**
 * A class to calculate MD5 checksums over a block of data. The
 * checksum can be calculated incrementally, i.e. the data can be passed
 * to the generator in several iterations.
 */
class VHIST_EXTERN MD5Generator : public QObject
{
    Q_OBJECT
    public: // construction, destruction and assignment
        MD5Generator(const QByteArray& data);
        MD5Generator();
        ~MD5Generator();
    
    public:
        void reset();
        void update(const QByteArray& data);
        QString getHexDigest();
    
    private:
        md5_state_t m_state;
        QString m_hexDigest;
};

} // namespace

#endif

