/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: validator.h 2792 2013-05-06 11:25:27Z michael $
 */

#ifndef VALIDATOR_INCLUDED
#define VALIDATOR_INCLUDED

#include "../shared/misc_defines.h"

#include <QObject>
#include <QString>

#include "md5generator.h"
#include "inflater.h"

class QByteArray;

namespace vhist
{

/**
 * @example validator_example.cpp
 * 
 * This example shows how to use the vhist::Validator.
 */

/**
 * A class for validating streams of data. The Validator tests if the streams
 * MD5 sum matches a given sum. If the datastream is compressed using flate
 * compression, the Validator will inflate the data on the fly and match the
 * MD5 sums of both, the compressed and uncompressed datastreams, with given
 * MD5 sums.
 */
class VHIST_EXTERN Validator : public QObject
{
    Q_OBJECT
    public: // construction, destruction, assignment
        Validator(const QString& md5 = "", const QString& compressedMD5 = "");
        virtual ~Validator();
        void reinit(const QString& md5, const QString& compressedMD5 = "");
    
    public:
        void update(const QByteArray& data);
        bool isValid();
    
    private: // member variables
        QString m_expectedMD5;
        QString m_expectedCompressedMD5;
        bool m_decompress;
        MD5Generator m_md5;
        MD5Generator m_compressedMD5;
        Inflater m_inflater;
};

}

#endif // VALIDATOR_INCLUDED

