/*
$Id: xmlit.h 2792 2013-05-06 11:25:27Z michael $
(c) Max-Planck-Institute for 
    Neurological Research (MPIFNF)
    Cologne, Germany 2005
    http://www.nf.mpg.de/vinci
    Email: vinci@nf.mpg.mpg.de
*/

/*
    VXMLLevel1Iter xi0=qs, xi1;
    xi0++;
    if (xi0.getTag() == "Level0" ) 
        for (xi1=xi0.getData();xi1;xi1++)
        {
            QString tag = xi1.getTag();
            QString data = xi1.getData();

            QString qst = QString("tag: %1, data: %2\n").arg(tag).arg(data);
            lprintf ( qst );
        }
    else
    {
        lprintf( "*** XML error.\n" );
    }
*/

#ifndef VT_XML_H
#define VT_XML_H

//#include "../include/misc_defines.h"

#ifndef USING_PCH
#include <QString>
#endif

namespace vhist
{

class VXMLLevel1Iter
{
public:
    VXMLLevel1Iter ( const QString &szXML );
    ~VXMLLevel1Iter ( );

    VXMLLevel1Iter(void);
    VXMLLevel1Iter(const VXMLLevel1Iter &anOther);

    VXMLLevel1Iter &operator=(const QString &szReInit);
    VXMLLevel1Iter &operator=(const VXMLLevel1Iter &anOther);
    
    inline const QString getTag(void) const;
    inline const QString getData(void) const;
    inline const QString getRemain(void) const;
    const QString getTagAndData(void) const;

    inline bool isTag(const QString szTestTag) const;
    inline bool isData(const QString szTestData) const;    
    inline int dataToInt() const;    
    inline double dataToDouble() const;    

    bool dataTo3Int(int &i1, int &i2, int &i3) const;
    bool dataTo3Double(double &r1, double &r2, double &r3) const;
    
    QString replaceCurrentTag(QString szReplacement);
    void setWithMsg(const bool bWithMsg)
        {m_bWithMsg=bWithMsg; }

    inline operator bool(void);
    inline operator const QString(void);

    const QString operator++(void);
    const QString operator++(int);

private:
    QString        m_szXMLOrig;
    QString        m_szXML;
    QChar*        m_pcXML;
    int            m_iCurPos;
    int            m_iLength;

    int            m_iDataBlockStart;    // -1, if undefined
    int            m_iDataBlockEnd;    // -1, if undefined

    bool        m_bOK;
    bool        m_bWithMsg;
    void Init (const QString &szXML);
    void Copy (const VXMLLevel1Iter &anOther);
    QChar        *pTag, *pData, *pEnd;
    int m_iTagSize,m_iDataSize;

    void getNextDataBlock(QChar **szData, int *iSizeData);

};

inline const QString VXMLLevel1Iter::getTag(void) const 
    {return m_bOK ? QString(pTag,m_iTagSize) : QString(); }

inline const QString VXMLLevel1Iter::getData(void) const 
    {return m_bOK ? QString(pData,m_iDataSize) : QString(); }

inline const QString VXMLLevel1Iter::getRemain(void) const 
    {return m_bOK ? QString(m_pcXML+m_iCurPos,m_iLength-m_iCurPos) : QString(); }


inline bool VXMLLevel1Iter::isTag(const QString szTestTag) const {
    return (getTag().compare(szTestTag) == 0);
}

inline bool VXMLLevel1Iter::isData(const QString szTestData) const {
    return (getData().compare(szTestData) == 0);
}

inline int VXMLLevel1Iter::dataToInt() const {
    return getData().toInt();
}

inline double VXMLLevel1Iter::dataToDouble() const {
    return getData().toDouble();
}

inline VXMLLevel1Iter::operator bool (void) 
{
    return m_bOK; 
}

inline VXMLLevel1Iter::operator const QString(void) 
    {return getData(); }


} // namespace

#endif // VT_XML_H

