/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: path.h 2179 2011-06-24 09:03:24Z ahuesgen $
 */

#ifndef PATH_INCLUDED
#define PATH_INCLUDED

#include <QHash>
#include <QLinkedList>
#include <QSharedPointer>

#include "../shared/misc_defines.h"
#include "diffdefines.h"

namespace vhist
{

template<class T>
class PriorityQueue;
class PathExpander;


class VHIST_EXTERN Path
{
    public:
        PathExpander* m_expander;
        Associations m_associations;
        Associations m_revAssociations;
        QHash<NodeId, bool> m_calcParentCostsLater;
        QLinkedList<NodeId> m_freeNodes1;
        QLinkedList<NodeId> m_freeNodes2;
        float m_curCosts;

    public: // getter
        NodeId association(NodeId nodeId, TreeId treeId) const;
        bool associated(NodeId nodeId, TreeId treeId) const;
        bool parentChanged(NodeId nodeId, TreeId treeId) const;

    public: // construction/destruction
        Path(PathExpander* expander);
        Path(const Path& rhs);
        ~Path();
        Path& operator=(const Path& rhs);

        void associate(NodeId node1, NodeId node2);
        bool reachedGoal();
        void expand(PriorityQueue<QSharedPointer<Path> >& m_queue);
        float getCosts();
        void printMe();
};


} // namespace vhist

#endif // PATH_INCLUDED
