/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistdiff.h 2179 2011-06-24 09:03:24Z ahuesgen $
 */

#ifndef VHISTDIFF_H
#define VHISTDIFF_H

#include <QSharedPointer>
#include <QList>
#include <QString>

#include "../shared/misc_defines.h"
#include "workflowtree.h"
#include "path.h"
#include "workflowstepcosts.h"
#include "vhistdiffresult.h"

namespace vhist
{

class Path;

class VHIST_EXTERN VhistDiff : public LogSource
{
    public:
        VhistDiff(const WorkflowTree& tree1, const WorkflowTree& tree2,
                WorkflowstepCosts* costs);
        ~VhistDiff();

    public:
        QSharedPointer<VhistDiffResult> findBestMatch() const;
        VhistDiffResults findBestMatches(int numMatches) const;

    public:
        void setTree1(const WorkflowTree& tree1);
        void setTree2(const WorkflowTree& tree2);
        void setCosts(WorkflowstepCosts* wfsCosts);

    public:
        WorkflowTree* tree1();
        WorkflowTree* tree2();
        WorkflowstepCosts* costs();

    private:
        VhistDiffResult convertPath(const Path& path) const;

    private:
        WorkflowTree m_tree1;
        WorkflowTree m_tree2;
        WorkflowstepCosts* m_wfsCosts;
};

} // namespace vhist


#endif // VHISTDIFF_H
