/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: queryerror.h 2168 2011-05-30 09:09:54Z ahuesgen $
 */

#ifndef PARSEQUERYERROR_H
#define PARSEQUERYERROR_H

#include "../shared/misc_defines.h"

#include <QString>
#include <QList>


namespace vhist
{

class VHIST_EXTERN QueryError
{
public:
    enum QueryErrorType
    {
        QUERY_ERROR_TYPE_ERROR,
        QUERY_ERROR_TYPE_WARNING
    };

public:
    QueryError(const QString& errorMsg, QueryErrorType type, int pos,
            const QString& originalText);

public:
    QString errorMessage() const;
    QString originalText() const;
    int position() const;
    int length() const;
    bool isError() const;
    bool isWarning() const;

private:
    QueryErrorType m_type;
    QString m_errorMsg;
    int m_pos;
    QString m_originalText;
};


typedef QList<QueryError> QueryErrors;

bool VHIST_EXTERN containsErrors(const QueryErrors& errors);
bool VHIST_EXTERN containsWarnings(const QueryErrors& errors);

}

#endif // PARSEQUERYERROR_H
