/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: returnvalue.h 2168 2011-05-30 09:09:54Z ahuesgen $
 */

#ifndef RETURNVALUE_H
#define RETURNVALUE_H

#include "../shared/misc_defines.h"

#include <QString>
#include <QDateTime>

namespace vhist
{

enum ReturnValueType
{
    RETURN_VALUE_BOOL,
    RETURN_VALUE_STRING,
    RETURN_VALUE_NOT_MATCHED,
    RETURN_VALUE_INVALID_TYPE,
    RETURN_VALUE_INVALID_OPERATOR,
    RETURN_VALUE_UNKNOWN_TOKEN_TYPE,
    RETURN_VALUE_NOT_ASSIGNED_YET
};


class ReturnValue
{
public:
    ReturnValue(ReturnValueType t, QString v);

public:
    bool isNumber() const;
    bool isDate() const;
    bool isString() const;
    bool isBool() const;
    bool isValid() const;
    bool isUnassignedVariable() const;
    
    QDateTime toDate(bool* success = NULL) const;
    float toNumber(bool* success = NULL) const;
    QString toString(bool* success = NULL) const;
    bool toBool(bool* success = NULL) const;

public:
    static ReturnValue fromString(const QString string);
    static ReturnValue fromBool(bool boolean);
    static ReturnValue fromNumber(float number);

public:
    bool operator ==(const ReturnValue& rhs);

private:
    ReturnValueType m_type;
    QString m_value;
};

}

#endif // RETURNVALUE_H
