/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: stopwatch_example.cpp 2179 2011-06-24 09:03:24Z ahuesgen $
 */

#include <shared/stopwatch.h>
#include <QObject>

// this class will handle our performance measurement results
class Logger : public QObject
{
    Q_OBJECT
    public slots:
        void log(const QString msg, const int type);
};

void Logger::log(const QString msg, const int type)
{
    // do something with the log messages
    std::cout << msg.toStdStr() << std::endl;
}


// ...

// create a logger
Logger logger;

// create a stopwatch
vhist::StopWatch watch(&logger);

// start timing
watch.start("first performance test");
doSomeStuff();

// this call will stop the first timing sequence
watch.start("second performance test");
doOtherStuff();

// explicitly stop the last timing sequence
watch.stop();


