/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: operatorinfo.cpp 2169 2011-05-30 09:11:44Z ahuesgen $
 */

#include "../../include/vhistfindlib/operatorinfo.h"

using namespace vhist;


int vhist::getPrecedence(const QString& op)
{
    if (op == "!")                return 9;
    else if (op == "&&")          return 2;
    else if (op == "implizit &&") return 2;
    else if (op == "||")          return 3;
    else if (op == "==")          return 4;
    else if (op == "!=")          return 4;
    else if (op == "<")           return 5;
    else if (op == "<=")          return 5;
    else if (op == ">")           return 5;
    else if (op == ">=")          return 5;
    else if (op == "%contains")   return 6;
    else if (op == "%matches")    return 6;
    else if (op == "%isapprox")   return 6;
    else if (op == "(")           return 0;
    else if (op == ")")           return 0;
    else if (op == "EOS")         return -100;
    else
        return -1;
}


char vhist::getAssociation(const QString& op)
{
    if (op == "!")                return 'r';
    else if (op == "&&")          return 'l';
    else if (op == "implizit &&") return 'l';
    else if (op == "||")          return 'l';
    else if (op == "==")          return 'l';
    else if (op == "!=")          return 'l';
    else if (op == "<")           return 'l';
    else if (op == "<=")          return 'l';
    else if (op == ">")           return 'l';
    else if (op == ">=")          return 'l';
    else if (op == "%contains")   return 'l';
    else if (op == "%matches")    return 'l';
    else if (op == "%isapprox")   return 'l';
    else if (op == "(")           return 'x';
    else if (op == ")")           return 'x';
    else if (op == "EOS")         return 'x';
    else
        return 'x';
}


int vhist::getNumArguments(const QString& op)
{
    if (op == "!")                return 1;
    else if (op == "&&")          return 2;
    else if (op == "implizit &&") return 2;
    else if (op == "||")          return 2;
    else if (op == "==")          return 2;
    else if (op == "!=")          return 2;
    else if (op == "<")           return 2;
    else if (op == "<=")          return 2;
    else if (op == ">")           return 2;
    else if (op == ">=")          return 2;
    else if (op == "%contains")   return 2;
    else if (op == "%matches")    return 2;
    else if (op == "%isapprox")   return 2;
    else if (op == "(")           return 0;
    else if (op == ")")           return 0;
    else if (op == "EOS")         return 0;
    else
        return -1;
}
