/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: queryerror.cpp 2169 2011-05-30 09:11:44Z ahuesgen $
 */

#include "../../include/vhistfindlib/queryerror.h"

using namespace vhist;

// helper functions

bool vhist::containsErrors(const QueryErrors& errors)
{
    for (int i = 0; i < errors.length(); ++i)
    {
        if (errors.at(i).isError())
            return true;
    }
    return false;
}


bool vhist::containsWarnings(const QueryErrors& errors)
{
    for (int i = 0; i < errors.length(); ++i)
    {
        if (errors.at(i).isWarning())
            return true;
    }
    return false;
}


// class members

QueryError::QueryError(const QString& errorMsg,
        QueryErrorType type, int pos, const QString& originalText)
        : m_type(type), m_errorMsg(errorMsg), m_pos(pos),
        m_originalText(originalText)
{
}


QString QueryError::errorMessage() const
{
    return m_errorMsg;
}


QString QueryError::originalText() const
{
    return m_originalText;
}


int QueryError::position() const
{
    return m_pos;
}


int QueryError::length() const
{
    return m_originalText.length();
}


bool QueryError::isError() const
{
    return m_type == QUERY_ERROR_TYPE_ERROR;
}


bool QueryError::isWarning() const
{
    return m_type == QUERY_ERROR_TYPE_WARNING;
}
