/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: main.cpp 2144 2011-05-11 14:25:03Z ahuesgen $
 */

#include <QApplication>
#include <QStringList>
#include <QFileOpenEvent>
#include <QTimer>

#include <iostream>
#include <fstream>
#include <QtDebug>

#include "shared/windowlist.h"
#include "shared/constants.h"
#include "shared/opendispatcher.h"
#include "shared/helpviewer.h"
#include "shared/registerwindows.h"

#include <vhistfindlib/returnvalue.h>


#include <QDateTime>

void setOrganizationInfo()
{
    QCoreApplication::setApplicationName(VHISTZARD_FULLNAME);
    QCoreApplication::setApplicationVersion(VHISTZARD_VERSION);
    QCoreApplication::setOrganizationName(VHISTZARD_ORGANIZATION);
    QCoreApplication::setOrganizationDomain(VHISTZARD_DOMAIN);
    QApplication::setWindowIcon(QIcon(":/resources/vhistzard1-64.png"));
}


void handleCommandlineArguments(QApplication& app)
{
    QStringList args = app.arguments();
    for (int i = 1; i < args.size(); i++)
    {
        QString filename = args.at(i);
        QFileOpenEvent* oevent = new QFileOpenEvent(filename);
        app.postEvent(&app, oevent);
    }
}


int main(int argc, char* argv[])
{
    // init application
    QApplication app(argc, argv);
    setOrganizationInfo();

    // set window list
    WindowList winList;
    WindowList::setGlobalInstance(&winList);
    registerWindows();
    
    // set global help viewer class for viewing documentation
    HelpViewer viewer;
    HelpViewer::setGlobalInstance(&viewer);
    
    // handles file open events
    OpenDispatcher opener;
    app.installEventFilter(&opener);
    
    // read commandline options
    handleCommandlineArguments(app);
    
    // if a file open request was send, call the open file handler
    // of the window list
    QObject::connect(&opener, SIGNAL(openFileRequested(const QString&)),
            &winList, SLOT(openFile(const QString&)));
    
    // register window switching handler (to update window menu)
    QObject::connect(&app, SIGNAL(focusChanged(QWidget*, QWidget*)), 
            &winList, SLOT(focusChanged()));
    
    // calls createFirstWindow after the application has been started and
    // preceeding events have been handled. Will open a window if no window
    // has been opened by any event.
    QTimer::singleShot(30, &winList, SLOT(createFirstWindow()));
    
    // start application
    return app.exec();
}
