/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: argfilehighlighter.h 2683 2013-04-16 14:14:01Z ahuesgen $
 */

#ifndef ARGFILEHIGHLIGHTER_H
#define ARGFILEHIGHLIGHTER_H

#include <arglib/argfileparser.h>

#include <QSyntaxHighlighter>

enum ArgTokenStyle
{
    ARG_TOKEN_STYLE_NORMAL,
    ARG_TOKEN_STYLE_BOLD,
    ARG_TOKEN_STYLE_ITALIC
};


class ArgFileHighlighter : public QSyntaxHighlighter
/**
 * Highlights errors in a query string inside a QueryTextField.
 */
{
    Q_OBJECT
public:
    ArgFileHighlighter();
    ~ArgFileHighlighter();

public:
    virtual void highlightBlock(const QString& text);

private:
    void highlightString(int pos, int length, const QColor& color,
            ArgTokenStyle style);

    void handleComment(const vhist::ArgfileToken& token, const QColor& color);
    void handleArgument(const vhist::ArgfileToken& token,
            const QList<QSet<QString> >& tokenLists,
            const QList<QColor>& colorList, const QColor& defaultColor);
    void handleRest(const vhist::ArgfileToken& token, const QColor& color,
            int tokensSinceLastArgument);

};

#endif // ARGFILEHIGHLIGHTER_H
