/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: findbar.cpp 2681 2013-04-16 14:09:31Z ahuesgen $
 */

#include "findbar.h"

#include <QtDebug>
#include <QHBoxLayout>

FindBar::FindBar(QWidget* parent) :
    QWidget(parent)
{
    initWidget();
    initSlots();
    hideFindBar();
}


QString FindBar::findString()
{
    return m_searchEdit->text();
}


bool FindBar::caseSensitive()
{
    return m_caseSensitiveCheck->checkState() == Qt::Checked;
}


void FindBar::initWidget()
{
    //QIcon::setThemeName("oxygen");
    //qDebug() << QIcon::themeName();
    QHBoxLayout* hlayout = new QHBoxLayout(this);
    setLayout(hlayout);
    hlayout->setContentsMargins(0, 0, 0, 0);

    m_closeButton = new QToolButton(this);
    m_closeButton->setText(tr("X"));
    m_closeButton->setIcon(QIcon::fromTheme("window-close"));
    m_closeButton->setIconSize(QSize(16, 16));
    hlayout->addWidget(m_closeButton);

    m_searchEdit = new FindEdit(this);
    hlayout->addWidget(m_searchEdit);

    m_prevButton = new QToolButton(this);
    m_prevButton->setText(tr("<"));
    m_prevButton->setIcon(QIcon::fromTheme("go-previous"));
    m_prevButton->setIconSize(QSize(16, 16));
    hlayout->addWidget(m_prevButton);

    m_nextButton = new QToolButton(this);
    m_nextButton->setText(tr(">"));
    m_nextButton->setIcon(QIcon::fromTheme("go-next"));
    m_nextButton->setIconSize(QSize(16, 16));
    hlayout->addWidget(m_nextButton);

    m_caseSensitiveCheck = new QCheckBox(tr("Case sensitive"), this);
    hlayout->addWidget(m_caseSensitiveCheck);

    QSpacerItem* spacer = new QSpacerItem(40, 0, QSizePolicy::Expanding);
    hlayout->addSpacerItem(spacer);
}


void FindBar::initSlots()
{
    connect(m_closeButton, SIGNAL(clicked()), this, SLOT(hideFindBar()));
    connect(m_prevButton, SIGNAL(clicked()), this, SIGNAL(previousPressed()));
    connect(m_nextButton, SIGNAL(clicked()), this, SIGNAL(nextPressed()));
    connect(m_searchEdit, SIGNAL(textChanged(QString)), this,
            SIGNAL(findStringChanged(QString)));
    connect(m_caseSensitiveCheck, SIGNAL(toggled(bool)), this,
            SIGNAL(caseSensitivityChanged(bool)));
    connect(m_searchEdit, SIGNAL(escapePressed()), this, SLOT(hideFindBar()));
    connect(m_searchEdit, SIGNAL(returnPressed()), this, SIGNAL(nextPressed()));
    connect(m_searchEdit, SIGNAL(shiftReturnPressed()), this,
            SIGNAL(previousPressed()));
}


void FindBar::hideFindBar()
{
    setVisible(false);
    emit findBarHidden();
}


void FindBar::showFindBar()
{
    setVisible(true);
    m_searchEdit->setFocus();
    emit findBarShown();
}

