/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: findbar.h 2681 2013-04-16 14:09:31Z ahuesgen $
 */

#ifndef FINDBAR_H
#define FINDBAR_H


#include "findedit.h"

#include <QWidget>

#include <QToolButton>
#include <QCheckBox>

class FindBar : public QWidget
{
    Q_OBJECT
public:
    explicit FindBar(QWidget* parent = 0);

public:
    QString findString();
    bool caseSensitive();

public slots:
    void hideFindBar();
    void showFindBar();

signals:
    void previousPressed();
    void nextPressed();
    void findStringChanged(QString text);
    void caseSensitivityChanged(bool caseSensitive);
    void findBarHidden();
    void findBarShown();

private:
    void initWidget();
    void initSlots();

private:
    QToolButton* m_closeButton;
    FindEdit* m_searchEdit;
    QToolButton* m_prevButton;
    QToolButton* m_nextButton;
    QCheckBox* m_caseSensitiveCheck;
};

#endif // FINDBAR_H
