/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: helpviewer.cpp 2457 2011-07-29 09:24:21Z ahuesgen $
 */

#include "helpviewer.h"

#include <QString>
#include <QStringList>
#include <QFileInfo>
#include <QMessageBox>
#include <QLibraryInfo>
#include <QtDebug>
#include <QDir>
#include <QDesktopServices>
#include <QUrl>
#include "utilities.h"


HelpViewer* HelpViewer::M_globalViewer = NULL;


QString HelpViewer::getDocPath(const QString& filename)
{
    QString docPath(joinPaths(getDocDir(), filename));
    return makePathCanonical(docPath);
}


HelpViewer::HelpViewer(QObject* parent) : QObject(parent)
{
}

void HelpViewer::viewError(const QString& message)
{
    QMessageBox::warning(NULL, tr("Online Documentation"),
            message);
}


void HelpViewer::openPage(const QString& page, const QString& anchor)
{
    QString docPath = getDocPath(page);
    //qDebug() << "docpath" << docPath;
    if (docPath == "")
        return;
    QUrl url = QUrl::fromLocalFile(docPath);
    url.setFragment(anchor);
    //qDebug() << "html page: " << url;
    QDesktopServices::openUrl(url);
    //QDesktopServices::openUrl(QUrl("http://www.nf.mpg.de/vhist/doc/vhist-usage.htm#sec-1.2"));
}


void HelpViewer::setGlobalInstance(HelpViewer* viewer)
{
    HelpViewer::M_globalViewer = viewer;
}


HelpViewer* HelpViewer::globalInstance()
{
    return HelpViewer::M_globalViewer;
}


void HelpViewer::globalOpenPage(const QString& page, const QString& anchor)
{
    HelpViewer* viewer = globalInstance();
    if (viewer != NULL)
        viewer->openPage(page, anchor);
}

