/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: managedwindow.cpp 2807 2013-05-07 15:55:54Z ahuesgen $
 */

#include "managedwindow.h"

#include <QMenuBar>
#include <QMenu>
#include <QAction>

QMenu* ManagedWindow::getWindowMenu()
{
    return m_windowMenu;
}

void ManagedWindow::activate()
{
    activateWindow();
    raise();
}

/**
 * Initializes menu entries shared by all Windows, e.g. New * Window, Close,
 * Quit, and the Window menu. This method has no effect if the window does
 * not have any menubar.
 *
 * @param[in] winMenuBefore The menu before which the window menu should
 * be inserted. if \a winMenuBefore is \c NULL, the window menu is appended
 * at the end of the menubar.
 */
void ManagedWindow::initSharedMenu(const QString& recentFilesConfig)
{
    // init shared menu
    m_windowMenu = m_sharedMenu.initMenu(*this, recentFilesConfig);
    connect(&m_sharedMenu, SIGNAL(recentFileSelected(QString)), this,
            SIGNAL(recentFileSelected(QString)));
}


void ManagedWindow::removeMainMenu()
{
    m_sharedMenu.removeRecentFiles();
    m_windowMenu = NULL;

    QMenuBar *mb = menuBar();
    setMenuBar(NULL);
    if (mb != NULL)
        delete mb;
}


void ManagedWindow::updateWindowMenu()
{
    m_sharedMenu.updateWindowMenu();
}


void ManagedWindow::createWindow(const QString& type, const QString& filename)
{
    m_sharedMenu.createWindow(type, filename);
}

void ManagedWindow::addRecentFile(const QString& filename)
{
    m_sharedMenu.addRecentFile(filename);
}
