/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: managedwindow.h 2807 2013-05-07 15:55:54Z ahuesgen $
 */

#ifndef MANAGEDWINDOW_INCLUDED
#define MANAGEDWINDOW_INCLUDED

#include <QMainWindow>
#include "shared/sharedmenu.h"

class QMenu;
class QAction;

class ManagedWindow : public QMainWindow
{
    Q_OBJECT
    
    public:
        QMenu* getWindowMenu();
        void initSharedMenu(const QString& recentFilesConfig = "");
        void addRecentFile(const QString& filename);
        void updateWindowMenu();
        void removeMainMenu();
    
    public slots:
        void activate();
        void createWindow(const QString& type, const QString& filename = "");
    
    signals:
        void recentFileSelected(QString filename);
    
    private:
        SharedMenu m_sharedMenu;
        QMenu* m_windowMenu;
};

#endif // MANAGEDWINDOW_INCLUDED

