/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: registerwindows.cpp 2172 2011-06-06 07:27:14Z ahuesgen $
 */

#include <QDebug>

#include "shared/windowlist.h"

#include "unvhist/unvhistwindow.h"
#include "vhistez/mainwindow.h"
#include "vhistit/vhistitwindow.h"
#include "vhistfind/vhistfindwindow.h"

void registerWindows()
{
    WindowList* wlist = WindowList::globalInstance();

    if (wlist != NULL)
    {
        // register unVHIST window (+ default)
        WindowType unvhistType(UnVHISTWindow::windowName(),
                UnVHISTWindow::windowShortcut(),
                QStringList() << "vhist" << "pdf",
                UnVHISTWindow::createUnVHISTWindow);
        wlist->registerWindowType(unvhistType);
        wlist->setDefaultWindowType(UnVHISTWindow::windowName());

        // register VHISTez window
        WindowType vhistEzType(MainWindow::windowName(),
                MainWindow::windowShortcut(), QStringList(),
                MainWindow::createVHISTezWindow);
        wlist->registerWindowType(vhistEzType);

        // register VHISTit window
        WindowType vhistItType(VHISTitWindow::windowName(),
                VHISTitWindow::windowShortcut(), QStringList() << "vcmd",
                VHISTitWindow::createVHISTitWindow);
        wlist->registerWindowType(vhistItType);

        // register VHISTfind window
        WindowType vhistFindType(VhistFindWindow::windowName(),
                VhistFindWindow::windowShortcut(), QStringList(),
                VhistFindWindow::createVHISTFindWindow);
        wlist->registerWindowType(vhistFindType);
    }
    else
        qDebug() << "window list not initialized";
}
