/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: sharedmenu.h 2807 2013-05-07 15:55:54Z ahuesgen $
 */

#ifndef SHAREDMENU_INCLUDED
#define SHAREDMENU_INCLUDED

#include <QObject>

class QMainWindow;
class QMenu;
class QString;
class RecentFiles;

class SharedMenu : public QObject
{
    Q_OBJECT
    
    public:
        SharedMenu();
    public:
        QMenu* initMenu(QMainWindow& win, const QString& recentFilesConfig = "");
        void updateWindowMenu();
        
    public slots:
        void createWindow(const QString& type, const QString& filename = "");
        void showAboutDialog();
        void addRecentFile(QString filename);
        void removeRecentFiles();
    
    signals:
        void recentFileSelected(QString filename);

    private:
        QStringList getRecentFiles(const QString& configname);
        void initFileMenu(QMenu& fileMenu, QMainWindow& win,
                const QString& configname);
        void initToolsMenu(QMenu& toolsMenu);
        void initHelpMenu(QMenu& helpMenu);

        QMenu* findMenu(QMainWindow& win, const QString& title);
        QMenu* createMenuBefore(QMainWindow& win, const QString& title, const QString& before);

    private:
        RecentFiles* m_recentFiles;
};

#endif // SHAREDMENU_INCLUDED

