/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: utilities.h 2036 2010-07-16 11:55:05Z ahuesgen $
 */

#ifndef UTILITIES_INCLUDED
#define UTILITIES_INCLUDED

#include <QString>
#include <QDateTime>
#include <QHash>
#include <QMap>

class QStringList;
class QDir;

// html helpers
QString makeBold(const QString& input);
QString makeRed(const QString& input);
QString makeOrange(const QString& input);
QString escapeHtml(const QString& input);

// path helpers
QString getApplicationDir();
QString getBinaryDir();
QString getDocDir();
QString getBinDir();
QString getTemplatesDir();
QString getExamplesDir();

QString makePathAbsolute(const QString& path);
QString makePathCanonical(const QString& path);
QString joinPaths(const QString& path1, const QString& path2);
//QString movePathUp(QString path, int count = 1);
QString firstExistingFile(const QString& basePath, const QStringList& files);
QString firstExistingPath(const QString& basePath, const QStringList& files);

// file manipulation helpers
bool copyDirectory(const QDir& srcDir, const QDir& destDir);
bool removeDirectory(const QDir& dir);

QString getDateTimeAsString(const QDateTime &dt, 
							const bool bComma /*= true*/);
QString getCurrentDateTimeAsString();

class VWaitCursor {
 public:
	VWaitCursor();
	~VWaitCursor();
};

QString getComputerName(); 

template<class Key, class Value>
QMap<Key, Value>* convertHashToMap (QHash<Key, Value>* input) // WARNING: Needs to be moved
{
	QMap<Key, Value>* newmap = new QMap<Key, Value> ();

	QHash<QString, QString>::const_iterator is = input->constBegin();
	while (is != input->constEnd()) {
		newmap->insert (is.key (), is.value ());
		++is;
	}

	return (newmap);
}

#endif // UTILITIES_INCLUDED

