/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: windowlist.h 2167 2011-05-30 09:06:57Z ahuesgen $
 */

#ifndef WINDOWLIST_INCLUDED
#define WINDOWLIST_INCLUDED

#include <QObject>
#include <QList>
#include <QPair>

#include "shared/windowtype.h"

class ManagedWindow;
class QMenu;
class QWidget;

typedef QPair<ManagedWindow*, WindowType> WindowListItem;

class WindowList : public QObject
{
    Q_OBJECT
    
    // member functions
    public:
        WindowList(QString szTemplatesDir = QLatin1String(""));
        virtual ~WindowList();
    
    public:
        void registerWindowType(const WindowType& descriptor);
        void setDefaultWindowType(const QString name);
        QHash<QString, WindowType> getRegistratedWindowTypes();

    public slots:
        void createWindow(const QString& typeName, const QString& filename = "",
                const QVariantHash& parameters = QVariantHash());
        void createFirstWindow();
        void openFile(const QString& filename);
        
        void removeWindow(QObject* win);
        void removeAllWindows(void);
        void makeNextWindowActive();
        void makePrevWindowActive();
        void focusChanged();
        void updateAllMenus();

    private:
        bool letWMPlaceWindow();
        void addWindow(ManagedWindow& win, const WindowType& type);
        void placeWindow(ManagedWindow& win);
        void initWindow(ManagedWindow& win, const WindowType& type);
        void showWindow(ManagedWindow& win);
        void updateWindowMenu(QMenu& windowMenu);
        QList<WindowListItem>::iterator findWindow(QWidget* win);
    
    // member variables
    private:
        QHash<QString, WindowType> m_windowTypes;
        QList<WindowListItem> m_windowList;
        QString m_defaultWindowType;
        QWidget* m_lastActiveWindow;
    
    // static functions and variables
    public:
        static void setGlobalInstance(WindowList* list);
        static WindowList* globalInstance();
    
    private:
        static WindowList* M_globalList;
        QString m_szTemplatesDir;
};

#endif // WINDOWLIST_INCLUDED
