/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: windowtype.cpp 2167 2011-05-30 09:06:57Z ahuesgen $
 */

#include "windowtype.h"

WindowType::WindowType()
{
}


WindowType::WindowType(const QString& name, const QString& shortcut,
        const QStringList& associatedTypes, WindowCreatorFn windowCreator)
        : m_name(name), m_shortcut(shortcut),
        m_associatedTypes(associatedTypes), m_windowCreator(windowCreator)
{
}


WindowType::WindowType(const WindowType& rhs) : m_name(rhs.m_name),
        m_shortcut(rhs.m_shortcut), m_associatedTypes(rhs.m_associatedTypes),
        m_windowCreator(rhs.m_windowCreator)
{
}


WindowType::~WindowType()
{
}


QString WindowType::name() const
{
    return m_name;
}


QString WindowType::shortcut() const
{
    return m_shortcut;
}


QStringList WindowType::associatedTypes() const
{
    return m_associatedTypes;
}


WindowCreatorFn WindowType::windowCreator() const
{
    return m_windowCreator;
}
