/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: validationqueue.h 1449 2008-10-17 11:43:50Z ahuesgen $
 */

#ifndef EXTRACTDIALOG_INCLUDED
#define EXTRACTDIALOG_INCLUDED

#include "ui_extract.h"
#include <QStringList>

class ExtractDialog : public QDialog, public Ui::ExtractDialog
{
    Q_OBJECT
    public:
        ExtractDialog(QWidget* parent = NULL, const QString& directory = "", int numFiles = 0);
        virtual ~ExtractDialog();
        void initSignalSlots();

    public:
        QString getDirectory();
        bool getAskBeforeOverwrite();
        bool getValidateFiles();

    public slots:
        void uiChanged();

    public slots:
        void setAdjustFilenamesActive(int);

        QStringList adjustFilenames(const QStringList& filenames);
        QString adjustFilename(const QString& filename, int numFiles, int fileNum);
        QString replacePlaceholders(const QString mask, const QString filename,
              int fileNumber, int numDigits);
        bool filenameMaskValid();
        bool directoryValid();
        void browseForDirectory();
        void showLegendHelp();

    private:
        QStringList m_files;
        QString m_hiddenLegend;
        QString m_visibleLegend;
};


#endif // EXTRACTDIALOG_INCLUDED

