/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: argfile.h 2054 2010-12-17 13:29:30Z michael $
 */

#ifndef MAKETREE_H
#define MAKETREE_H

#include <QString>
#include <QStringList>
#include <QPair>
#include <QTreeWidgetItem>

const int TAG_TYPE_ROLE = Qt::UserRole + 1;
const int TAG_ID_ROLE = Qt::UserRole + 2;
const int TAG_ANCHOR_ROLE = Qt::UserRole + 3;


struct FileData
{
    QString filename;
    int id;
    QString anchor;
};

enum TagType
{
    SECTION_TAG_TYPE = 1,
    FILE_TAG_TYPE = 2,
    DIR_TAG_TYPE = 3
};

QTreeWidgetItem* makeOutlineItem(const QString& title,
        TagType type, int id, const QString& anchor);


QTreeWidgetItem* treeFromFileList(const QList<FileData>& files);

QString getCommonPrefix(QStringList filenames);
QString lastPartOfPath(const QString& path);
QString makePathValid(const QString& path);
QStringList splitPath(const QString& path);

#endif // MAKETREE_H
