/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: parsetemplate.h 2123 2011-04-29 12:39:37Z ahuesgen $
 */

#include <QString>
#include <QList>
#include <QHash>

#include <unvhistlib/summary.h>

class Block;

QString makeSectionAnchor(int sectionID);
QString makeFileAnchor(int sectionID, int posInSection);

class ParseTemplate : public QObject
{
    Q_OBJECT
        
 public:
    ParseTemplate(QObject *pLogTarget = NULL);
    ~ParseTemplate();
    void loadTemplateFile(QString szTemplateFile);
    QString generateHtml(const QString szFileName,
                         const QString szTemplateFile,
                         const vhist::Summaries& summaries,
                         bool bGeneratePDF);
 private:
    int m_maxpos;
    int m_iFilesInSection;
    QString m_szTemplate;

    bool m_bEvenOddHandling;
    bool m_nextEvenOddIsOdd;
    
    QList<Block*> m_LNamedBlocks;
    QHash<QString, Block*> m_HNamedBlocks;
    QHash<QString, QString> m_HOneSection;

    int m_numStepUserAttrs;
    QList<int> m_LnumFileUserAttrs;

    int m_numStepPreviews;
    QList<int> m_LnumFilePreviews;

    void cleanup(void);
    QString generateOneBlock(const QString szBlockName,
                             QHash<QString, QString> indexVars,
                             bool bKeepEvenOdd = false);
    QString expandContents(const QString szContents, const QHash<QString, QString> indexVars);
    
    bool parser(void);
    void addContents(Block *pb, int iStart, int iEnd);
    int addNamedBlock(Block *pb, int markerpos);
    int addMarker(Block *pb, int markerpos);
    static const QString m_szMarker;
    static const QString m_szIFDEF;
    static const QString m_szIFNDEF;
    static const QString m_szIFEQUAL;
    static const QString m_szELSE;
    static const QString m_szENDIF;
    static const QString m_szBEGINBLOCK;
    static const QString m_szENDBLOCK;
    
    static const QString m_szEVENODDBEGIN;
    static const QString m_szEVENODDEND;
    static const QString m_szEVEN;
    static const QString m_szODD;
    static const QString m_szKeywordEvenOdd;
    static const QString m_szKeywordUserKey;
    
    static const QString m_szMEND;
    static const QString m_szBracketOpen;
    static const QString m_szBracketClose;
    static const QString m_szMAINBLOCKNAME;
    static const QString m_szTOPBLOCKNAME;
    static const QString m_szBOTTOMBLOCKNAME;
    static const QString m_szFILESBLOCKNAME;
    static const QString m_szUSERATTRBLOCKNAME;
    static const QString m_szUSERFILEATTRBLOCKNAME;
    static const QString m_szPREVIEWWSBLOCKNAME;
    static const QString m_szPREVIEWFILEBLOCKNAME;
    
    static const QString m_szDUMPALLBLOCKNAME;
    static const QString m_szDUMPENTRYBLOCKNAME;
    
    static const QString m_szKeywordRegex;
    static const int m_iLenMEND;
    static const int m_iLenMarker;

 signals:
    void log(const QString szText);    
};
