/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: preferences.h 1456 2008-10-22 10:16:59Z jnock $
 */
#ifndef PREFERENCES_INCLUDED
#define PREFERENCES_INCLUDED

#include <QLatin1String>
#include <QVariant>

// Our custom datatypes
enum SizeChoice {
	SMALL,
	MEDIUM,
	LARGE
};

enum ActionChoice {
	ALWAYS,
	NEVER,
	DEPENDS
};

// This is the model for the UnVHIST preferences.
// Note that every function that is commented with 
// META doesn't directly correspond to an item in QSettings.
// These are little helpers that take care of configuration items
// that can effectively be modified by other configuration items.
class Preferences {
public:
	// Log
	static QString logFontFamily ();
	static void setLogFontFamily (const QString&);

	static qreal logFontPointSize ();
	static void setLogFontPointSize (qreal);

	static unsigned logShow ();
	static void setLogShow (unsigned);

	// Browser
	static QString browTemplate ();
	static void setBrowTemplate (const QString&);

	static int browZoomLevel ();
	static void setBrowZoomLevel (int);

	// Validation 
	static SizeChoice valPerformance ();
	static void setValPerformance (SizeChoice);

	static ActionChoice valAutomaticFileValidation ();
	static void setValAutomaticFileValidation (ActionChoice);

	static unsigned valAFVLimit ();
	static void setValAFVLimit (unsigned);

	static ActionChoice valAutomaticSectionValidation ();
	static void setValAutomaticSectionValidation (ActionChoice);

	static unsigned valASVLimit ();	
	static void setValASVLimit (unsigned);

	// Extraction
	static unsigned extrAskBeforeOverwrite ();
	static void setExtrAskBeforeOverwrite (unsigned);

	static unsigned extrValidateFiles ();
	static void setExtrValidateFiles (unsigned);

	static unsigned extrNumberFiles ();
	static void setExtrNumberFiles (unsigned);

	static ActionChoice extrValidateAfter ();
	static void setExtrValidateAfter (ActionChoice);

	static unsigned extrVAELimit ();
	static void setExtrVAELimit (unsigned);

	static QString extrLastDirectory ();
	static void setExtrLastDirectory (const QString&);

	static unsigned extrDefaultDirectory ();
	static void setExtrDefaultDirectory (unsigned);

	// Extraction META
	static QString extrDirectory (); // META - This is the method if you just want to know where to effectively store the files

private:
	// Helper functions
	static QString getString (const QString&, const QString&);
	static qreal getReal (const QString&, const qreal);
	static unsigned getInt (const QString&, const unsigned);

	static void setValue (const QString&, const QVariant&);
};

#endif // PREFERENCES_INCLUDED
