/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistbrowser.h 1964 2010-04-29 12:57:27Z michael $
 */

#ifndef VHISTBROWSER_INCLUDED
#define VHISTBROWSER_INCLUDED

#include <QTextBrowser>
#include <QColor>

namespace vhist
{
    class VhistParser;
}

class VhistBrowser : public QTextBrowser
{
    Q_OBJECT
    public:
        VhistBrowser(QWidget* parent = 0);
        ~VhistBrowser();
        void setParser(vhist::VhistParser* parser);
    
    public:
        virtual QVariant loadResource(int type, const QUrl& name);
        void enableFind(bool enabled);
        bool findEnabled();
    
        void setContextMenu (QMenu*);
    
        int zoom ();
        void setZoom (int);
    
    public slots:
        void findStringChanged(const QString& findString);
        void findNext(int position = -1);
        void findPrev(int position = -1);
        void zoomIn (int range = 1);
        void zoomOut (int range = 1);
    
    private:
        int getIDFromUrl(const QUrl& name);
    
    protected:
        virtual void keyPressEvent(QKeyEvent* event);
        virtual void contextMenuEvent(QContextMenuEvent* event);
        virtual void wheelEvent (QWheelEvent* event);
    
    private:
        vhist::VhistParser* m_parser;
        QString m_findString;
        bool m_findEnabled;
        QMenu* m_contextmenu;
        int m_zoomLevel;
};

#endif // VHISTBROWSER_INCLUDED

