/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: exporttabcontextmenu.cpp 1456 2008-12-31 10:16:59Z jnock $
 */
#include "exporttabcontextmenu.h"

ExportTabContextMenu::ExportTabContextMenu (QWidget* q)
{
	// The actions
	m_CopyToClipboardAction=new QAction(tr("&Copy To Clipboard"),this);
    m_SaveAsArgFileAction=new QAction(tr("&Save as Arg File"),this);
    m_SaveAndOpenAction=new QAction(tr("&Save And Open"),this);

	// The signals
	connect (m_CopyToClipboardAction, SIGNAL(triggered()), this, SLOT(copySlot()));
	connect (m_SaveAsArgFileAction, SIGNAL(triggered()), this, SLOT(saveSlot()));
	connect (m_SaveAndOpenAction, SIGNAL(triggered()), this, SLOT(saveAndOpenSlot()));

	// The menu
	m_menu = new QMenu (q);
	m_menu->addAction(m_CopyToClipboardAction);
	m_menu->addAction(m_SaveAsArgFileAction);
	m_menu->addAction(m_SaveAndOpenAction);
}

void ExportTabContextMenu::exec ()
{
	m_menu->exec(QCursor::pos());
}

void ExportTabContextMenu::copySlot ()
{
	copyChosen ();
}

void ExportTabContextMenu::saveSlot ()
{
	saveChosen ();
}

void ExportTabContextMenu::saveAndOpenSlot ()
{
	saveAndOpenChosen ();
}
