/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 Author: Joachim Nock
 $Id: fileitemhelper.cpp 1630 2009-04-05 14:15:53Z jnock $
 */
#include "fileitemhelper.h"
#include "guiwindow.h"

const unsigned TMP_UR_FILEOBJECT = Qt::UserRole + 7;

FileItemHelper::FileItemHelper (GuiWindow* gw) : QObject (gw)
{
	m_list = gw->FileListWidget;

	m_selectedItem = NULL;
}

vhist::WSFile* FileItemHelper::getFile (QListWidgetItem* item)
{
//	return ((File*)item->data (TMP_UR_FILEOBJECT).toULongLong ());
	QVariant value = item->data (TMP_UR_FILEOBJECT);
	void* ptr;
	
	ptr = value.value<void*> ();

	return ((vhist::WSFile*)ptr);
}

vhist::WSFile* FileItemHelper::getSelectedFile ()
{
	if (m_selectedItem == NULL) {
		return (NULL);
	}

	return (getFile (m_selectedItem));
}

QString FileItemHelper::getSelectedFilename ()
{
	if (m_selectedItem == NULL) {
		return (NULL);
	}

	return (getSelectedFile ()->filename ());
}

QListWidgetItem* FileItemHelper::getSelectedItem()
{
	return (m_selectedItem);
}

void FileItemHelper::setUpNewPair (QListWidgetItem* item, vhist::WSFile* file)
{
	QVariant value;

	value.setValue<void*> (file);
	
	item->setData (TMP_UR_FILEOBJECT, value);	
	//item->setData (TMP_UR_FILEOBJECT, (qulonglong)file);
}

void FileItemHelper::setSelectedItem (QListWidgetItem* ni)
{
	m_selectedItem = ni;
}

void FileItemHelper::clearSelections ()
{
	QList<QListWidgetItem *> list= m_list->selectedItems();
	while ((!list.isEmpty())) {
		m_selectedItem=list.takeFirst();
		m_selectedItem->setSelected(0);
	}

	m_selectedItem = NULL;
}

int FileItemHelper::getSelectedIndex ()
{
	QListWidgetItem* item = getSelectedItem ();
	return (m_list->row (item));
}
