/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: guiwindow.h 2458 2011-08-03 09:21:52Z ahuesgen $
 */

#ifndef GUIWINDOW_H
#define GUIWINDOW_H

#include "ui_vhistez.h"
#include <QDir>
#include <QDialog>
#include <arglib/argfile.h>
#include "lock.h"
#include "lockall.h"
#include "locknone.h"
#include "maintabcontextmenu.h"
#include "inouttabcontextmenu.h"
#include "vhistfilestabcontextmenu.h"
#include "exporttabcontextmenu.h"
#include "fileitemhelper.h"
#include "../shared/helpviewer.h"
#include "../shared/argfilehighlighter.h"

class QAction;
class QLabel;
class QShowEvent;
class QResizeEvent;
class PreferencesWindow;
class ManagedWindow;

class GuiWindow: public QWidget, public Ui::GuiWindow
{
        Q_OBJECT

public:
        // Constants - FIXME: they all need a different naming
        static const QString m_userDefinedFileType;
        static const QString m_string_InputTextAtFileListWidget;
        static const QString m_string_OutputTextAtFileListWidget;
        static const QString m_attributeSplitter; // DUP
        static const QString m_spaceAlias; // DUP

        GuiWindow(QString szApplicationDir, ManagedWindow* parent);
		~GuiWindow ();

        QString buildCommand_File(bool);

        int m_row;
        lock* m_lockStrategy;
        int m_number;
        int m_contextMenuStatus;
       
        bool m_noItemInList;
        bool m_lock;
        bool m_optional;
        QString m_fileDescriptionTextOld;

        QString m_other;
        QString m_text;
        QString m_binary;
        QString m_xml;
        QString m_storageFileNameAndPath;
        QString m_quietRadioButtin;
        QString m_toolVersionText;
        QBrush m_greenBrush;
        enum m_FileStates {EMBEDDED = 32, MD5=33, MD5ANDEMBEDDED=34, NONE=35, OPTIONAL=36,NOTOPTIONAL=37}; // TODO: Remove
        enum m_FileRoles {INPUT=38,OUTPUT=39};
        void clearAllFilesAttributes();
        void clearAllToolAttributes();
        void addNewRowToGeneralAttributesTable();
        void store_cmdFileToDisk(QFile*);
        void connectSlots();
        void on_FileListWidget_clicked();
        void contextMenu();
        PreferencesWindow *m_preferencesWindow;

	MainTabContextMenu* m_maintabcm;
	InOutTabContextMenu* m_inouttabcm;
	VhistFilesTabContextMenu* m_vhistfilestabcm;
	ExportTabContextMenu* m_exporttabcm;
protected:
        void dropEvent(QDropEvent *event);
        void dragEnterEvent(QDragEnterEvent* event);
        void showEvent(QShowEvent* event);
        void resizeEvent(QResizeEvent* event);
//        void contextMenuEvent(QContextMenuEvent *event);
public slots:
        void openArgFile(const QString& filename);
private slots:
		
		void setAppendMode();		
void on_fileAttributesTable_cellChanged(int row, int colum);
void on_generalAttributesTable_cellChanged(int, int);
void on_pathText_editingFinished();
void on_removeAllAttributes_clicked();
void checkFreeWidgetItems();
void on_removeAllFileValuePairs_clicked();
void on_removeAllFilesButton_clicked();
void on_removeAttributes_clicked();
void on_removeFileKeyValuePairs_clicked();
void on_toolNameText_editingFinished();
void on_toolPathText_editingFinished();
void on_toolBrowserButton_clicked();
void on_fileBrowserButton_clicked();
void on_inputRadioButton_clicked();
void on_saveAsCmdFileButton_clicked();
void on_saveRunButton_clicked();
void on_outputRadioButton_clicked();
void on_fileAttributesTable_itemSelectionChanged();
void on_generalAttributesTable_itemSelectionChanged();
void on_removeFileButton_clicked();
void openVHISTEZHelp();
void save_cmdfile();
void on_tabWidget_currentChanged(int);
void on_FileListWidget_itemSelectionChanged();
void on_clipBoardButton_clicked();
void on_newFileButton_clicked();
void on_embedFileCheckBox_clicked();
void on_md5CheckBox_clicked();
void on_previewWSCheckBox_clicked();
void on_previewCheckBox_clicked();
void on_thumbnailCheckBox_clicked();
void on_verboseRadioButton_clicked();
void on_normalRadioButton_clicked();
void on_pretendCheckBox_clicked();
void on_quietRadioButton_clicked();
void on_fileTypeSelector_activated(const QString&);
void on_descriptionText_textChanged ();
void on_fileTypeLineEdit_textChanged(const QString& changedText);
void on_duplicateFileButton_clicked();
void on_fileText_returnPressed();
void on_vhistRootFileBrowserButton_clicked();
void on_vhistStorageFileBrowserButton_clicked();
void on_noneCheckBox_clicked();
void on_vhistRootOptionalCheckBox_stateChanged(int);
void on_oneUserSpecificVhistOutFileRadioButton_clicked();
void on_userspecifiedPathAndNameRadioButton_clicked();
void on_firstOutputFileVhist_clicked();
void on_one_EachOutputFileRadioButton_clicked();
void on_firstInputFileVhistRootFileRadioButton_clicked();
void on_vhistStorageFileNameText_editingFinished();
void on_vhistStorageFilePathText_editingFinished();
void on_vhistRootFilePathText_editingFinished();
void on_vhistRootFileNameText_editingFinished();
void on_optionalCheckBox_clicked();
void on_fileText_editingFinished();
void on_pathText_returnPressed();
//void on_relativePathText_focusInEvent(QFocusEvent*);
void applyToThisFile_clicked();
void open_cmdfile ();
void go_mainAct ();
void go_inoutfilesAct();
void go_vhistfilesAct();
void go_exportAct();
void on_versionLineEdit_editingFinished ();
void on_titleLineEdit_editingFinished ();
void on_workflowDescriptionTextEdit_textChanged ();
QString adjustRelativity (QString);
void on_relativePathsCheckBox_stateChanged (int);
#ifdef VDEBUG
	QString toolOperationToString ();
	QString inputNameSource ();
	QString outputNameSource ();
	void go_export ();
#endif
private:
      

void guaranteePathTextEndsWithSlashOrBackSlash();
void updateToolAttributesTable();
void setStatisticsText();
void updateNumberOfFilesLabel();
void initializeWorklfowKeyValuePairs();
void evaluateRadioButtons();
void processFileData(QString, QString);
void changeFileListItemName(const QString&);
void setUpVariables_Start();
void setUpMimeTypeList();
void setDefaults();
void removeOneToolAttribute(int);
void setTool(QString);
void dragMoveEvent(QDragMoveEvent*);
void addFile(vhist::WSFile*);
void buildCommand(QString, QString);
void setInOrOutFile(bool);
void set_Quiet_Verbose_pretend();
void createMenus();
void update_AttributesFileLabel();
void reset_GeneralAttribtuesLabel();
void reset_AttributesFileLabel();
void update_GeneralAttributesLabel();
void handle_visibility_InOutFileTab();
void setLineEditTextToBlank();
void initCommandline();
void setButtonsVisibleAfterNew();
void countTotalNumberOfAttributes();
void setHints(QString);
void setButtonVisibleAfterBrowse();
void hideAllButtons();
void checkFreeWidgetItemsfiles(QString);
void loadFileAttributesTable();
void setAllVisible();
void handleStorageFileAndPathChange();
void handleFilePathAndNameEditLineChange();
void readAttributesOfFileItem();
void setGroupBox(QListWidgetItem*);
void storeToItem();
void handle_cellChanges(QTableWidget*, int, int);
void preventToSelectedItemsInDifferentListWidgets(QString);
void handleRootFileAndPathChange();
void handleProblemWithMd5AtFirstElement(QListWidgetItem *newItem);
void constructionTab();
void guessMimeType ();
void loadIOFileName ();

QString extractXML1(QString szXML, QString szKey) const;
QString getVhistInfo() const;
QString generateWokflowDescriptionCommandlineStatement();
QString makeCommentAboutUserDefinedAttributes();
QString makeCommentAboutUserDefinedAttributes(QListWidgetItem*);
QString generateGeneralOptionsCommandlineStatement();
QString returnHints(QString);
QString getApplicationDir() const;
QString getFileAttributes();
QString m_szApplicationDir, m_szDocDir;
ManagedWindow* m_parent;

ArgFileHighlighter m_highlighter;
vhist::ArgFile* m_argfile; // This is the model behind this window
FileItemHelper* m_fihelper; // This is a helper to control the aspect of mapping QListWidgetItem* to File*, which has unfortunately proven itself to be not that trivial as one might think it should be

};
#endif

