/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: InOutTabContextMenu.cpp 1456 2008-12-26 10:16:59Z jnock $
 */
#include "inouttabcontextmenu.h"

InOutTabContextMenu::InOutTabContextMenu (QWidget* parent)
{
	// The actions
    m_FileBrowserButtonAction=new QAction(tr("&Browse..."),this);
    m_NewFileAction=new QAction(tr("&Add File"),this);
    m_copyAction=new QAction(tr("&copy"),this); // TODO: Unused?
    m_RemoveFileAction=new QAction(tr("&Remove File"),this);
    m_DuplicateFileAction=new QAction(tr("&Duplicate File"),this);
    m_RemoveAllFilesAction=new QAction(tr("&Remove All Files"),this);
    m_EmbedFileAction=new QAction(tr("&Embed File"),this);
	m_EmbedFileAction->setCheckable (true);
    m_CalculateFileAction=new QAction(tr("&Calculate MD5"),this);
	m_CalculateFileAction->setCheckable(true);
    m_OptionalFileAction=new QAction(tr("&Optional"),this);
	m_OptionalFileAction->setCheckable(true);
	m_PreviewWSAction=new QAction(tr("&Preview WS"),this);
	m_PreviewWSAction->setCheckable(true);
	m_PreviewAction=new QAction(tr("&Preview"),this);
	m_PreviewAction->setCheckable(true);
	m_ThumbnailAction=new QAction(tr("&Thumbnail"),this);
	m_ThumbnailAction->setCheckable(true);
    m_TypeAction=new QAction(("&Change To Output File"),this);

	// The slots
	connect (m_FileBrowserButtonAction, SIGNAL(triggered()), this, SLOT(fileBrowserSlot()));
	connect (m_NewFileAction, SIGNAL(triggered()), this, SLOT(addFileSlot()));
	connect (m_RemoveFileAction, SIGNAL(triggered()), this, SLOT(removeFileSlot()));
	connect (m_DuplicateFileAction, SIGNAL(triggered()), this, SLOT(duplicateFileSlot()));
	connect (m_RemoveAllFilesAction, SIGNAL(triggered()), this, SLOT(removeAllFilesSlot()));
	connect (m_TypeAction, SIGNAL(triggered()), this, SLOT(toOutputSlot ()));
	connect (m_CalculateFileAction, SIGNAL(triggered ()), this, SLOT(calculateSlot ()));
	connect (m_EmbedFileAction, SIGNAL(triggered ()), this, SLOT(embedSlot ()));
	connect (m_OptionalFileAction, SIGNAL(triggered ()), this, SLOT(optionalSlot ()));
	connect (m_PreviewWSAction, SIGNAL(triggered ()), this, SLOT(previewWSSlot ()));
	connect (m_PreviewAction, SIGNAL(triggered ()), this, SLOT(previewSlot ()));
	connect (m_ThumbnailAction, SIGNAL(triggered ()), this, SLOT(thumbnailSlot ()));

	// The menu
	m_menu = new QMenu (parent);

	m_FileBrowserButtonAction->setEnabled (false);
	m_menu->addAction(m_FileBrowserButtonAction);

	m_menu->addSeparator();
	m_menu->addAction(m_NewFileAction);
	m_RemoveFileAction->setEnabled (false);
    m_menu->addAction(m_RemoveFileAction);               
	m_DuplicateFileAction->setEnabled (false);
	m_menu->addAction(m_DuplicateFileAction);
	m_RemoveAllFilesAction->setEnabled (false);
    m_menu->addAction(m_RemoveAllFilesAction);
	m_menu->addAction(m_TypeAction);
	m_TypeAction->setEnabled (false);
	m_menu->addSeparator();

	m_OptionalFileAction->setEnabled (false);
	m_menu->addAction(m_OptionalFileAction);
	m_EmbedFileAction->setEnabled (false);	
	m_menu->addAction(m_EmbedFileAction);
	m_CalculateFileAction->setEnabled (false);
	m_menu->addAction(m_CalculateFileAction);
	m_PreviewWSAction->setEnabled (false);
	m_menu->addAction(m_PreviewWSAction);
	m_PreviewAction->setEnabled (false);
	m_menu->addAction(m_PreviewAction);
	m_ThumbnailAction->setEnabled (false);
	m_menu->addAction(m_ThumbnailAction);
}

InOutTabContextMenu::~InOutTabContextMenu ()
{
	delete m_menu;
}

void InOutTabContextMenu::exec ()
{
	m_menu->exec(QCursor::pos());
}

void InOutTabContextMenu::adjustCheckStates (vhist::WSFile* selectedfile)
{
	m_CalculateFileAction->setChecked(selectedfile->autoMD5());
	m_EmbedFileAction->setChecked(selectedfile->embed ());
	m_OptionalFileAction->setChecked(selectedfile->optional ());
	m_PreviewWSAction->setChecked(selectedfile->previewWS ());
	m_PreviewAction->setChecked(selectedfile->preview ());
	m_ThumbnailAction->setChecked(selectedfile->thumbnail ());
}

void InOutTabContextMenu::setFileOperations (bool how)
{
	m_FileBrowserButtonAction->setEnabled (how);
	m_RemoveFileAction->setEnabled (how);
	m_DuplicateFileAction->setEnabled (how);
	m_RemoveAllFilesAction->setEnabled (how);
	m_TypeAction->setEnabled (how);
	m_OptionalFileAction->setEnabled (how);
	m_EmbedFileAction->setEnabled (how);	
	m_CalculateFileAction->setEnabled (how);
	m_PreviewWSAction->setEnabled (how);
	m_PreviewAction->setEnabled (how);
	m_ThumbnailAction->setEnabled (how);
}

void InOutTabContextMenu::doInput ()
{
	m_TypeAction->setText (("&Change To Output File"));
	disconnect (m_TypeAction, SIGNAL(triggered()), this, SLOT(toInputSlot ()));
	connect (m_TypeAction, SIGNAL(triggered()), this, SLOT(toOutputSlot ()));}

void InOutTabContextMenu::doOutput ()
{
	m_TypeAction->setText (("&Change To Input File"));
	disconnect (m_TypeAction, SIGNAL(triggered()), this, SLOT(toOutputSlot ()));
	connect (m_TypeAction, SIGNAL(triggered()), this, SLOT(toInputSlot ()));
}

void InOutTabContextMenu::doCalculate ()
{
	m_CalculateFileAction->setChecked (!m_CalculateFileAction->isChecked ());
}

void InOutTabContextMenu::doEmbed ()
{
	m_EmbedFileAction->setChecked (!m_EmbedFileAction->isChecked ());
}

void InOutTabContextMenu::doOptional ()
{
	m_OptionalFileAction->setChecked (!m_OptionalFileAction->isChecked ());
}

void InOutTabContextMenu::doPreviewWS ()
{
	m_PreviewWSAction->setChecked (!m_PreviewWSAction->isChecked ());
}

void InOutTabContextMenu::doPreview ()
{
	m_PreviewAction->setChecked (!m_PreviewAction->isChecked ());
}

void InOutTabContextMenu::doThumbnail ()
{
	m_ThumbnailAction->setChecked (!m_ThumbnailAction->isChecked ());
}

// --- Private --- 

// TODO: These only forward, too
void InOutTabContextMenu::fileBrowserSlot ()
{
	fileBrowserChosen ();
}

void InOutTabContextMenu::addFileSlot ()
{
	addFileChosen ();
}

void InOutTabContextMenu::removeFileSlot ()
{
	removeFileChosen ();
}

void InOutTabContextMenu::duplicateFileSlot ()
{
	duplicateFileChosen ();
}

void InOutTabContextMenu::removeAllFilesSlot ()
{
	removeAllFilesChosen ();
}

void InOutTabContextMenu::toInputSlot ()
{
	toInputChosen ();
}

void InOutTabContextMenu::toOutputSlot ()
{
	toOutputChosen ();
}

void InOutTabContextMenu::calculateSlot ()
{
	m_CalculateFileAction->setChecked (!m_CalculateFileAction->isChecked ()); // Unfortunately, a small hack
	calculateChosen ();
}

void InOutTabContextMenu::embedSlot ()
{
	m_EmbedFileAction->setChecked (!m_EmbedFileAction->isChecked ()); // Unfortunately, a small hack
	embedChosen ();
}

void InOutTabContextMenu::optionalSlot ()
{
	m_OptionalFileAction->setChecked (!m_OptionalFileAction->isChecked ()); // Unfortunately, a small hack
	optionalChosen ();
}

void InOutTabContextMenu::previewWSSlot ()
{
	m_PreviewWSAction->setChecked (!m_PreviewWSAction->isChecked ()); // Unfortunately, a small hack
	previewWSChosen ();
}

void InOutTabContextMenu::previewSlot ()
{
	m_PreviewAction->setChecked (!m_PreviewAction->isChecked ()); // Unfortunately, a small hack
	previewChosen ();
}

void InOutTabContextMenu::thumbnailSlot ()
{
	m_ThumbnailAction->setChecked (!m_ThumbnailAction->isChecked ()); // Unfortunately, a small hack
	thumbnailChosen ();
}

