/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: InOutTabContextMenu.h 1456 2008-12-26 10:16:59Z jnock $
 */
#ifndef INOUTTABCONTEXTMENU_INCLUDED
#define INOUTTABCONTEXTMENU_INCLUDED

#include <QMenu>
#include <QWidget>

#include <arglib/wsfile.h>

class InOutTabContextMenu : public QObject {
	Q_OBJECT
public:
	InOutTabContextMenu (QWidget*);
	~InOutTabContextMenu ();

	void adjustCheckStates (vhist::WSFile*);
	void setFileOperations (bool);

signals:
	void fileBrowserChosen ();
	void addFileChosen ();
	void removeFileChosen ();
	void duplicateFileChosen ();
	void removeAllFilesChosen ();
	void toOutputChosen ();
	void toInputChosen ();
	void calculateChosen ();
	void embedChosen ();
	void optionalChosen ();
	void previewWSChosen ();
	void previewChosen ();
	void thumbnailChosen ();

public slots:
	void exec ();

	void doInput ();
	void doOutput ();
	void doCalculate ();
	void doEmbed ();
	void doOptional ();
	void doPreviewWS ();
	void doPreview ();
	void doThumbnail ();

private slots:
	void fileBrowserSlot ();
	void addFileSlot ();
	void removeFileSlot ();
	void duplicateFileSlot ();
	void removeAllFilesSlot ();
	void toInputSlot ();
	void toOutputSlot ();
	void calculateSlot ();
	void embedSlot ();
	void optionalSlot ();
	void previewWSSlot ();
	void previewSlot ();
	void thumbnailSlot ();

private:
	QMenu* m_menu;

	QAction* m_OptionalFileAction;
	QAction* m_FileBrowserButtonAction;
	QAction* m_TypeAction;
	QAction* m_copyAction;
	QAction* m_NewFileAction;
	QAction* m_RemoveFileAction;
	QAction* m_DuplicateFileAction;
	QAction* m_RemoveAllFilesAction;
	QAction* m_EmbedFileAction;
	QAction* m_CalculateFileAction;
	QAction* m_PreviewWSAction;
	QAction* m_PreviewAction;
	QAction* m_ThumbnailAction;
};

#endif /* INOUTTABCONTEXTMENU_INCLUDED */

