/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: MainTabContextMenu.cpp 1456 2008-12-25 10:16:59Z jnock $
 */
#include "maintabcontextmenu.h"

MainTabContextMenu::MainTabContextMenu (QWidget* window)
{
	// Actions
	m_ToolBrowserButtonAction = new QAction (tr ("&Browse"), this);
	m_NormalRadioButtonAction = new QAction (tr ("&Normal"), this);
	m_NormalRadioButtonAction->setCheckable (true);
	m_NormalRadioButtonAction->setChecked (true);
	m_QuietRadioButtonAction = new QAction (tr ("&Quiet"), this);
	m_QuietRadioButtonAction->setCheckable (true);
	m_VerboseRadioButtonAction = new QAction (tr ("&Verbose"), this);
	m_VerboseRadioButtonAction->setCheckable (true);
	m_PretendCheckBox = new QAction (tr ("&Pretend"), this);
	m_PretendCheckBox->setCheckable (true);

	// Slots
	connect (m_ToolBrowserButtonAction, SIGNAL (triggered()), this, SLOT (toolBrowserSlot()));
	connect (m_NormalRadioButtonAction, SIGNAL (triggered()), this, SLOT (normalSlot()));
	connect (m_NormalRadioButtonAction, SIGNAL (triggered()), this, SLOT (doNormal()));
	connect (m_QuietRadioButtonAction, SIGNAL (triggered()), this, SLOT (quietSlot()));
	connect (m_QuietRadioButtonAction, SIGNAL (triggered()), this, SLOT (doQuiet()));
	connect (m_VerboseRadioButtonAction, SIGNAL (triggered()), this, SLOT (verboseSlot()));
	connect (m_VerboseRadioButtonAction, SIGNAL (triggered()), this, SLOT (doVerbose()));
	connect (m_PretendCheckBox, SIGNAL (triggered()), this, SLOT (pretendSlot()));
	connect (m_PretendCheckBox, SIGNAL (triggered()), this, SLOT (doPretend ()));

	// Menu
	m_menu = new QMenu (window);
	m_menu->addAction(m_ToolBrowserButtonAction);
	m_menu->addSeparator();
	m_menu->addAction(m_NormalRadioButtonAction);
	m_menu->addAction(m_QuietRadioButtonAction);
	m_menu->addAction(m_VerboseRadioButtonAction);
	m_menu->addAction(m_PretendCheckBox);
}

MainTabContextMenu::~MainTabContextMenu ()
{
	// Actions
	delete m_ToolBrowserButtonAction;
	delete m_NormalRadioButtonAction;
	delete m_QuietRadioButtonAction;
	delete m_VerboseRadioButtonAction;
	delete m_PretendCheckBox;

	// Menu
	delete m_menu;
}

void MainTabContextMenu::exec ()
{
	m_menu->exec (QCursor::pos ());
}

void MainTabContextMenu::doNormal ()
{
	m_NormalRadioButtonAction->setChecked (true);
	m_QuietRadioButtonAction->setChecked (false);
	m_VerboseRadioButtonAction->setChecked (false);
}

void MainTabContextMenu::doQuiet ()
{
	m_NormalRadioButtonAction->setChecked (false);
	m_QuietRadioButtonAction->setChecked (true);
	m_VerboseRadioButtonAction->setChecked (false);
}

void MainTabContextMenu::doVerbose ()
{
	m_NormalRadioButtonAction->setChecked (false);
	m_QuietRadioButtonAction->setChecked (false);
	m_VerboseRadioButtonAction->setChecked (true);
}

void MainTabContextMenu::doPretend ()
{
	m_PretendCheckBox->setChecked (!m_PretendCheckBox->isChecked ());
}

// --- Private ---

// TODO: They only forward. Can't the signal be the slot immediately?
void MainTabContextMenu::toolBrowserSlot ()
{
	toolBrowserChosen ();
}

void MainTabContextMenu::normalSlot ()
{
	normalChosen ();
}

void MainTabContextMenu::quietSlot ()
{
	quietChosen ();
}

void MainTabContextMenu::verboseSlot ()
{
	verboseChosen ();
}

void MainTabContextMenu::pretendSlot ()
{
	pretendChosen ();
}
