/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: MainTabContextMenu.h 1456 2008-12-25 10:16:59Z jnock $
 */
#ifndef MAINTABCONTEXTMENU_INCLUDED
#define MAINTABCONTEXTMENU_INCLUDED

#include <QMenu>

class MainTabContextMenu : public QObject {
	Q_OBJECT

public:
	MainTabContextMenu (QWidget*);
	~MainTabContextMenu ();

signals:
	void toolBrowserChosen ();
	void normalChosen ();
	void quietChosen ();
	void verboseChosen ();
	void pretendChosen ();

public slots:
	void exec ();

	void doNormal ();
	void doQuiet ();
	void doVerbose ();
	void doPretend ();

private slots:
	void toolBrowserSlot ();
	void normalSlot ();
	void quietSlot ();
	void verboseSlot ();
	void pretendSlot ();

private:
	QAction* m_ToolBrowserButtonAction;
	QAction* m_NormalRadioButtonAction;
	QAction* m_QuietRadioButtonAction;
	QAction* m_VerboseRadioButtonAction;
	QAction* m_PretendCheckBox;

	QMenu* m_menu;
};

#endif /* MAINTABCONTEXTMENU_INCLUDED */

