/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

Author: Michael May
$Id: mainwindow.h 2199 2011-06-28 15:09:48Z ahuesgen $
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QVariantMap>

#include "../shared/managedwindow.h"

class QString;

class GuiWindow;

class MainWindow: public ManagedWindow /* TODO: This class is nearly purely greedy on guiwindow. */
{
    Q_OBJECT 
        
public:
        MainWindow(const QString& filename = "");
        ~MainWindow();
        void call_exitAct();

public slots:
        void openArgFile(const QString& filename);
protected:
        void closeEvent(QCloseEvent *event);
        
private:
        void createActions();
        void createMenus();
        
        QString getApplicationDir() const;
        
        QMenu *fileMenu;
        QMenu *editMenu;
        QMenu *viewMenu;
        QMenu *helpMenu;
        QAction *openAct;
        QAction *saveAct;
        QAction *exitAct;
        QAction *cutAct;
        QAction *copyAct;
        QAction *pasteAct;
        QAction *aboutAct;
        QAction *go_mainAct;
        QAction *go_inoutfilesAct;      
        QAction *go_vhistfilesAct;      
        QAction *go_exportAct;
#ifdef VDEBUG
        QAction *exportAct;
#endif
        QAction *helpAct;
        QAction *preferencesAct;
        
public:
        GuiWindow *m_win;

public:
        static ManagedWindow* createVHISTezWindow(const QString& filename,
                const QVariantHash& parameters);
        static QString windowName();
        static QString windowShortcut();
};
#endif

