/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: mimetypes.cpp 1456 2008-11-22 10:16:59Z jnock $
 */
#include "mimetypes.h"

const QString MIMETYPES[] = {
"application/msword",
"application/octet-stream",
"application/pdf",
"application/postscript",
"application/vnd.oasis.opendocument.t",
"application/x-latex",
"application/x-tex",
"application/x-gzip",
"application/zip",
"binary/Analyze Header",
"binary/Analyze Image",
"binary/ECAT Image",
"binary/Interfile Image",
"binary/microPET Image",
"binary/NiFTI Image",
"image/bmp",
"image/gif",
"image/tiff",
"image/jpg",
"image/png",
"text/html",
"text/Interfile Header",
"text/microPET Header",
"text/rtf",
"text/plain",
"video/x-msvideo",
"video/quicktime",
"xml/Vinci Project File"
};

const unsigned MIMETYPECOUNT = 28;

const QString EXTENSIONMAPPING[] = {
"DOC", "application/msword", 
"EXE", "application/octet-stream",
"PDF", "application/pdf", 
"EPS", "application/postscript",
"ODT", "application/vnd.oasis.opendocument.t",
"LATEX", "application/x-latex",
"TEX", "application/x-tex",
"GZIP", "application/x-gzip",
"ZIP", "application/zip",
"BMP", "image/bmp",
"GIF", "image/gif",
"TIF", "image/tiff",
"TIFF", "image/tiff",
"JPG", "image/jpg",
"JPEG", "image/jpg",
"PNG", "image/png",
"HTM", "text/html",
"HTML", "text/html",
"RTF", "text/rtf",
"TXT", "text/plain",
"AVI", "video/x-msvideo",
"MOV", "video/quicktime"
};

const unsigned EXTENSIONMAPPINGCOUNT = 22;

QString Mimetypes::guessMimeType (const QString& filename)
{
	// Only if filename is given. If a filename is given, only changes when a good guess can be made.
	if (filename.contains ('.')) { // A . is contained, so there is a extension where we could try to guess the MIME type.
		QString extension = filename.mid (filename.lastIndexOf ('.') + 1);

		for (unsigned i = 0;i < EXTENSIONMAPPINGCOUNT;i++) {
			if (0 == QString::compare (EXTENSIONMAPPING[i*2], extension, Qt::CaseInsensitive)) { // Found
				// Set the mimetype to EXTENSIONMAPPING[i*2+1]
				return (EXTENSIONMAPPING[i*2+1]);
			}
		}
	} 

	return (""); // Nothing found
}

bool Mimetypes::isKnownMimeType (const QString& type)
{
	for (unsigned i = 0;i < MIMETYPECOUNT;i++) {
		if (MIMETYPES[i] == type) {
			return (true);
		}
	}

	return (false);
}

unsigned Mimetypes::getTypeCount ()
{
	return (MIMETYPECOUNT);
}

QString Mimetypes::getType (unsigned i)
{
	return (MIMETYPES[i]);
}
