/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: VhistFilesTabContextMenu.cpp 1456 2008-12-28 10:16:59Z jnock $
 */
#include <QMessageBox>

#include "vhistfilestabcontextmenu.h"

VhistFilesTabContextMenu::VhistFilesTabContextMenu (QWidget* q)
{
	// The actions
	m_appendAction = new QAction(tr("&Append"), this);
	m_appendAction->setCheckable (true);
	m_appendAction->setChecked (true);
    m_NoneTab2Action=new QAction(tr("&None"),this);
	m_NoneTab2Action->setCheckable (true);
	m_NoneTab2Action->setEnabled (false);
    m_optionalTab2Action=new QAction(tr("&Optional"),this); 
	m_optionalTab2Action->setCheckable (true);
	m_optionalTab2Action->setEnabled (false);
	m_FirstInputFileAction= new QAction(tr("&First Input File"),this);
	m_FirstInputFileAction->setCheckable (true);
	m_FirstInputFileAction->setChecked (true);
	m_FirstInputFileAction->setEnabled (false);
    m_FileWithUserspecifiedPathAndNameAction=new QAction(tr("&File With Userspecified Path and Name"),this);
	m_FileWithUserspecifiedPathAndNameAction->setCheckable (true);
	m_FileWithUserspecifiedPathAndNameAction->setEnabled (false);
    m_FirstOutputFileAction=new QAction(tr("&First Output File"),this);
	m_FirstOutputFileAction->setCheckable(true);
	m_FirstOutputFileAction->setChecked (true);
	m_FirstOutputFileAction->setEnabled (false);
    m_OneVhistFileWithUserSpecifiedPathAndNameAction=new QAction(tr("&One Vhist File With User Specified Path And Name "),this);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setCheckable (true);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setEnabled (false);
    m_OneForEachOutputFileAction=new QAction(tr("&One For Each Output File Action"),this);
	m_OneForEachOutputFileAction->setCheckable (true);
	m_OneForEachOutputFileAction->setEnabled (false);

	// Slots
	connect (m_appendAction, SIGNAL(triggered ()), this, SLOT(appendSlot ()));
	connect (m_NoneTab2Action, SIGNAL(triggered ()), this, SLOT(noneSlot ()));
	connect (m_optionalTab2Action, SIGNAL(triggered ()), this, SLOT(optionalSlot ()));
	connect (m_FirstInputFileAction, SIGNAL(triggered ()), this, SLOT(firstInputSlot ()));
	connect (m_FileWithUserspecifiedPathAndNameAction, SIGNAL(triggered ()), this, SLOT(userSpecSlot ()));
	connect (m_FirstOutputFileAction, SIGNAL(triggered()), this, SLOT(firstOutputSlot ()));
	connect (m_OneVhistFileWithUserSpecifiedPathAndNameAction, SIGNAL(triggered()), this, SLOT(outputUserSpecSlot ()));
	connect (m_OneForEachOutputFileAction, SIGNAL(triggered()), this, SLOT(oneForEachSlot ()));

	// Build the menu
	m_menu = new QMenu (q);

	m_menu->addAction(m_appendAction);
	m_menu->addSeparator ();
	m_menu->addAction(m_NoneTab2Action);
	m_menu->addSeparator();
	m_menu->addAction(m_optionalTab2Action);
	m_menu->addSeparator();
	m_menu->addAction(m_FirstInputFileAction);
	m_menu->addAction(m_FileWithUserspecifiedPathAndNameAction);
	m_menu->addSeparator();
	m_menu->addAction(m_FirstOutputFileAction);
	m_menu->addAction(m_OneVhistFileWithUserSpecifiedPathAndNameAction);
	m_menu->addAction(m_OneForEachOutputFileAction);
}

VhistFilesTabContextMenu::~VhistFilesTabContextMenu ()
{
	delete m_menu;
}

void VhistFilesTabContextMenu::exec ()
{
    m_menu->exec(QCursor::pos());
}

void VhistFilesTabContextMenu::doAppend ()
{
	m_appendAction->setChecked (!m_appendAction->isChecked ());
	m_NoneTab2Action->setEnabled (!m_appendAction->isChecked ());
	m_optionalTab2Action->setEnabled (!m_appendAction->isChecked () && !m_NoneTab2Action->isChecked ());
	m_FirstInputFileAction->setEnabled (!m_appendAction->isChecked ());
	m_FileWithUserspecifiedPathAndNameAction->setEnabled (!m_appendAction->isChecked ());
	m_FirstOutputFileAction->setEnabled (!m_appendAction->isChecked ());
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setEnabled (!m_appendAction->isChecked ());
	m_OneForEachOutputFileAction->setEnabled (!m_appendAction->isChecked ());
}

void VhistFilesTabContextMenu::doNone ()
{
	m_NoneTab2Action->setChecked (!m_NoneTab2Action->isChecked ());
	m_optionalTab2Action->setEnabled (!m_NoneTab2Action->isChecked ());
}

void VhistFilesTabContextMenu::doOptional ()
{
	m_optionalTab2Action->setChecked (!m_optionalTab2Action->isChecked ());
}

void VhistFilesTabContextMenu::doFirstInput ()
{
	m_FirstInputFileAction->setChecked (true);
	m_FileWithUserspecifiedPathAndNameAction->setChecked (false);
}

void VhistFilesTabContextMenu::doUserSpec ()
{
	m_FirstInputFileAction->setChecked (false);
	m_FileWithUserspecifiedPathAndNameAction->setChecked (true);
}

void VhistFilesTabContextMenu::doFirstOutput ()
{
	m_FirstOutputFileAction->setChecked (true);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (false);
	m_OneForEachOutputFileAction->setChecked (false);
}

void VhistFilesTabContextMenu::doOutputUserSpec ()
{
	m_FirstOutputFileAction->setChecked (false);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (true);
	m_OneForEachOutputFileAction->setChecked (false);
}

void VhistFilesTabContextMenu::doOneForEach ()
{
	m_FirstOutputFileAction->setChecked (false);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (false);
	m_OneForEachOutputFileAction->setChecked (true);
}

// --- Private ---
// TODO: Again only forwarding
void VhistFilesTabContextMenu::appendSlot ()
{
	m_appendAction->setChecked (!m_appendAction->isChecked ());
	appendChosen ();
}

void VhistFilesTabContextMenu::noneSlot ()
{
	m_NoneTab2Action->setChecked (!m_NoneTab2Action->isChecked ()); // Small hack revisited
	noneChosen ();
}

void VhistFilesTabContextMenu::optionalSlot ()
{
	m_optionalTab2Action->setChecked (!m_optionalTab2Action->isChecked ());
	optionalChosen ();
}

void VhistFilesTabContextMenu::firstInputSlot ()
{
	m_FirstInputFileAction->setChecked (true);
	m_FileWithUserspecifiedPathAndNameAction->setChecked (false);
	firstInputChosen ();
}

void VhistFilesTabContextMenu::userSpecSlot ()
{
	m_FirstInputFileAction->setChecked (false);
	m_FileWithUserspecifiedPathAndNameAction->setChecked (true);
	userSpecChosen ();
}

void VhistFilesTabContextMenu::firstOutputSlot ()
{
	m_FirstOutputFileAction->setChecked (true);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (false);
	m_OneForEachOutputFileAction->setChecked (false);
	firstOutputChosen ();
}

void VhistFilesTabContextMenu::outputUserSpecSlot ()
{
	m_FirstOutputFileAction->setChecked (false);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (true);
	m_OneForEachOutputFileAction->setChecked (false);
	outputUserSpecChosen ();
}

void VhistFilesTabContextMenu::oneForEachSlot ()
{
	m_FirstOutputFileAction->setChecked (false);
	m_OneVhistFileWithUserSpecifiedPathAndNameAction->setChecked (false);
	m_OneForEachOutputFileAction->setChecked (true);
	oneForEachChosen ();
}

