/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: VhistFilesTabContextMenu.h 1456 2008-12-28 10:16:59Z jnock $
 */
#ifndef VHISTFILESTABCONTEXTMENU_INCLUDED
#define VHISTFILESTABCONTEXTMENU_INCLUDED

#include <QMenu>
#include <QWidget>

class VhistFilesTabContextMenu : public QObject {
	Q_OBJECT
public:
	VhistFilesTabContextMenu (QWidget*);
	~VhistFilesTabContextMenu ();

signals:
	void appendChosen ();
	void noneChosen ();
	void optionalChosen ();
	void firstInputChosen ();
	void userSpecChosen ();
	void firstOutputChosen ();
	void outputUserSpecChosen ();
	void oneForEachChosen ();

public slots:
	void exec ();

	void doAppend ();
	void doNone ();
	void doOptional ();
	void doFirstInput ();
	void doUserSpec ();
	void doFirstOutput ();
	void doOutputUserSpec ();
	void doOneForEach ();

private slots:
	void appendSlot ();
	void noneSlot ();
	void optionalSlot ();
	void firstInputSlot ();
	void userSpecSlot ();
	void firstOutputSlot ();
	void outputUserSpecSlot ();
	void oneForEachSlot ();

private:
	QMenu* m_menu;
	QAction* m_appendAction;
    QAction* m_optionalTab2Action;
	QAction* m_NoneTab2Action;
    QAction* m_FirstInputFileAction;
    QAction* m_FileWithUserspecifiedPathAndNameAction;
    QAction* m_FirstOutputFileAction;
    QAction* m_OneVhistFileWithUserSpecifiedPathAndNameAction;
    QAction* m_OneForEachOutputFileAction;
};

#endif /* VHISTFILESTABCONTEXTMENU_INCLUDED */

