/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: queryhighlighter.h 2167 2011-05-30 09:06:57Z ahuesgen $
 */

#ifndef QUERYHIGHLIGHTER_H
#define QUERYHIGHLIGHTER_H

#include <QSyntaxHighlighter>

class QueryHighlighter : public QSyntaxHighlighter
/**
 * Highlights errors in a query string inside a QueryTextField.
 */
{
    Q_OBJECT
public:
    QueryHighlighter();
    ~QueryHighlighter();

public:
    virtual void highlightBlock(const QString& text);

private:
    void hightlightText(const QString& text, const QString& errorMessage,
            int pos, int length, const QColor& color);
signals:
    void errorOccurred(QString errorMessage, bool isError);
};

#endif // QUERYHIGHLIGHTER_H
