/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistfinder.h 2167 2011-05-30 09:06:57Z ahuesgen $
 */

#ifndef VHISTFINDER_H
#define VHISTFINDER_H

#include <QObject>
#include <QString>
#include <QStringList>
#include <QPair>

#include <vhistfindlib/vhistfindquery.h>

struct EvaluationResult
{
    EvaluationResult();
    QString filename;
    bool matches;
    QHash<QString, QString> associations;
};


class VhistFinder : public QObject
{
    Q_OBJECT
public:
    VhistFinder();
    ~VhistFinder();

    vhist::QueryErrors checkQuery(const QString& findQuery);
    vhist::QueryErrors init(const QString &findQuery, const QString & dir,
            bool invertResult);
    bool initialized();

public:
    EvaluationResult findNext();

public:
    int nextFileNumber();
    int numberOfFiles();

private:
    QStringList gatherVhistFiles(const QString& dir, bool followSymlinks);

private:
    QString m_findQuery;
    QString m_dir;
    QStringList m_files;
    int m_nextFile;
    vhist::VhistFindQuery m_query;
    bool m_invertResult;
};

#endif // VHISTFINDER_H
