/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistfindwindow.h 2167 2011-05-30 09:06:57Z ahuesgen $
 */

#ifndef VHISTFINDWINDOW_INCLUDED
#define VHISTFINDWINDOW_INCLUDED

#include <QDateTime>

#include <vhistfindlib/queryerror.h>

#include "shared/managedwindow.h"
#include "ui_vhistfindwindow.h"

#include "vhistfinder.h"


class VhistFindWindow: public ManagedWindow, public Ui::VhistFindWindow
{
    Q_OBJECT
    public: // construction, destruction and assignment
        VhistFindWindow(const QString& query, const QString& dir);
        ~VhistFindWindow();

    public:
        QStringList gatherVhistFiles(const QString& files, bool followSymlinks);

    signals:
        void processMoreFiles();

    private slots:
        void handleError(QString errorMessage, bool isError);
        void handleEnterPress();
        void findClicked();
        void browseForDir();
        void openVhistFile(const QUrl& link);

        void processSomeFiles();
        void handleResult(EvaluationResult& result, int testedSoFar, int total);
        void showHelp();

    public:
        static ManagedWindow* createVHISTFindWindow(const QString& filename,
                const QVariantHash& parameters);
        static QString windowName();
        static QString windowShortcut();

    private:
        VhistFinder m_finder;
};

#endif // VHISTFINDWINDOW_INCLUDED
