/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistaddrunner.cpp 1024 2008-05-23 11:20:34Z ahuesgen $
 */

#include "vhistaddrunner.h"

#include <QString>
#include <QtDebug>


/**
 * Constructor. Creates a new VhistaddRunner instance.
 */
VhistaddRunner::VhistaddRunner()
{
    connect(&m_thread, SIGNAL(outputUpdated(const QString&)),
            this, SIGNAL(outputUpdated(const QString&)));
    connect(&m_thread, SIGNAL(vhistaddFinished()),
            this, SIGNAL(vhistaddFinished()));
}


/**
 * Starts a new vhistadd process if none is currently running.
 * 
 * param[in] argfile The argfile used by vhistadd.
 * param[in] workingDir The current working directory used by the
 * vhistadd process.
 */
void VhistaddRunner::runVhistadd(const QString& argfile,
        const QString& workingDir)
{
    if (!m_thread.isRunning())
    {
        m_thread.init(argfile, workingDir);
        m_thread.start();
    }
}
