/* 
This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This application is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

 $Id: vhistitwindow.h 2459 2011-08-03 11:09:53Z ahuesgen $
 */

#ifndef VHISTITWINDOW_INCLUDED
#define VHISTITWINDOW_INCLUDED

#include <QWidget>
#include <ui_vhistit.h>

#include "../shared/managedwindow.h"
#include "../shared/argfilehighlighter.h"
#include "vhistaddrunner.h"


class QFileInfo;
class WindowList;
class QMenu;

class QDragEnterEvent;
class QDropEvent;
class QCloseEvent;

class VHISTitWindow: public ManagedWindow, public Ui::VHISTitWindow
{
    Q_OBJECT
    public: // construction, destruction and assignment
        VHISTitWindow(const QFileInfo* argfile = NULL);
        ~VHISTitWindow();
    
    private: // functions
        void initSignalSlots();
        void initHelloMessage();
        void setCwd(const QString& dirname);
        void setSelectionDirectory(const QString& directory);
    
    private: // member variables
        VhistaddRunner m_runner;
        bool m_jobRunning;
        QString m_selectionDirectory;
        ArgFileHighlighter m_highlighter;
    
    protected: // qt internas
        virtual void dragEnterEvent(QDragEnterEvent* event);
        virtual void dropEvent(QDropEvent* event);
        virtual void closeEvent(QCloseEvent* event);
    
    signals:
        void argfileUpdated(const QString& filename);
    
    protected slots:
        void setJobRunning(bool running);
        void finishJob();
        void startJob();
        void installExamples();
        
        void updateRunOption();

        void anchorClicked (const QUrl& link);
    
    public:
        bool isJobRunning();
        QString getArgfile();
        QString getSelectionDirectory();
    
    public slots:
        void setArgfile(const QString& filename);
        void editArgFile();
        void autoAdjustCwd(const QString&);
        void selectFile();
        void selectCwd();
        void disableCwdUi(bool syncing);
        void modifyTitle(const QString& cmdFile);
        
        void showArgfile(const QString& text);
        void runVhistadd();
        void updateCommandlineOutput(const QString& output);
        void showHelp();
        void setFilename(const QString& filename);

    public:
        static ManagedWindow* createVHISTitWindow(const QString& filename,
                const QVariantHash& parameters);
        static QString windowName();
        static QString windowShortcut();
};

#endif // VHISTITWINDOW_INCLUDED

