#!/usr/bin/env python
"""

This file is part of the VHIST project, http://www.nf.mpg.de/vhist,
which defines a file format suitable for documenting workflows. VHIST
files can store meta-data about the workflow and allow to embed
arbitrary binary data, such as images or log files, inside the
documentation. Embedded data can be validated using multiple facilities.
VHIST files can be viewed with any PDF browser.

(c) Max-Planck-Institute for Neurological Research (MPIFNF)
Cologne, Germany 2005 - 2013
Email: vhist@nf.mpg.de, http://www.nf.mpg.de/vhist

This script is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation
(LGPL version 2.1):

This application is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this application. If not, see
<http://www.gnu.org/licenses/>.

Author: Andreas Huesgen
$Id: compile-vhistzard.py 2305 2011-07-11 13:38:38Z ahuesgen $
"""

import shutil
import os, sys, glob

join = os.path.join

appname = sys.argv[0]
appdir = os.path.split(appname)[0]
appdir = os.path.abspath(appdir)

# sourcecode and bin directories
zardDir = join(appdir, "code/vhistzard/")
libDir = join(appdir, "code/vhistlib/")
binDir = join(appdir, "bin/")

# directories into which the library/executable is copied

def makeIt(moreOptions=""):
    make = "make"
    if sys.platform == "win32":
        make = "mingw32-make"

    print "calling qmake..."
    if os.system("qmake CONFIG+=release %s" % moreOptions) != 0:
        raise Exception("qmake failed. Make sure that Qt is installed")

    print "calling make clean..."
    if os.system("%s clean" % make) != 0:
        raise Exception("%s clean failed" % make)
    
    print "calling make..."
    if os.system(make) != 0:
        raise Exception("%s failed" % make)


def copyIt(filenames, binDir, binType):
    # copy all files/dirs from releaseDir to binDir
    for filename in filenames:
        srcpath = filename
        destpath = join(binDir, os.path.basename(filename))
        if os.path.isdir(srcpath):
            shutil.copytree(srcpath, destpath)
        elif os.path.isfile(srcpath):
            shutil.copy(srcpath, destpath)
        else:
            raise Exception("could not find %s '%s'" % (binType, srcpath))


def finishBundle():
    print "finishing Mac OS X Bundle..."
    libs = glob.glob("libvhistlib.*.dylib")
    os.mkdir("vhistzard.app/Contents/Frameworks")
    for lib in libs:
        shutil.move(lib, "vhistzard.app/Contents/Frameworks/")
        relPath = "@executable_path/../Frameworks/"
        os.system("install_name_tool -change '%s' '%s' '%s'" % (
                lib, join(relPath, lib),
                "vhistzard.app/Contents/MacOS/vhistzard"))

try:
    print "cd to %s..." % libDir
    os.chdir(libDir)
    
    print "building VHISTlib..."
    makeIt()
    
    print "copying libraries to bin directory..."
    # find libraries
    dllnames = []
    # linux, unix
    dllnames += glob.glob("bin/libvhistlib.so.*")
    # mac os x
    dllnames += glob.glob("bin/libvhistlib.*.dylib")
    # windows
    dllnames += glob.glob("../bin_win32/vhistlib.dll")
    dllnames += glob.glob("../bin_win32/zlib1.dll")
    
    if dllnames == []:
        raise Exception("Could not find any libraries")
    
    copyIt(dllnames, binDir, "library")
    
    #########################
    
    print "cd to %s..." % zardDir
    os.chdir(zardDir)
    
    print "building VHISTzard..."
    makeIt("LIBS+=-L../vhistlib/bin")
    
    print "copying executable to bin directory..."
    exename = ""
    # linux, unix
    if os.path.isfile(join(zardDir, "bin/vhistzard")):
        exename = "bin/vhistzard"
    # mac os x
    elif os.path.isdir(join(zardDir, "bin/vhistzard.app")):
        exename = "bin/vhistzard.app"
    # windows
    elif os.path.isfile(join(zardDir, "../bin_win32/vhistzard.exe")):
        exename = "../bin_win32/vhistzard.exe"
    
    if exename == "":
        raise Exception("Could not find any executable")
    
    copyIt([exename], binDir, "executable")
    
    ########################
    
    # move libs into bundle and call install_name_tool on mac os x
    if sys.platform ==  "darwin":
        os.chdir(binDir)
        finishBundle()
        os.chdir("..")
    else:
        os.chdir("../..")
    print "exiting..."

except Exception, e:
    print "An error occured:", e

